function Cdf = FunCdf(M,Re,l,S,Sref)
%--------------------------------------------------------------------------
% FunCdf(M,Re,l,S,Sref)
% FRICTION CALCULATOR
% Calculates the skin friction in all speed regimes for either the wing or body.
%--------------------------------------------------------------------------    
    %The Reynolds number for boundary layer transition from lam -> turb
    ReCr = 10^6;
    %Point on body of transition
    lCr = l*ReCr/Re;
    %Re evaluated for body length
    ReL = Re;
    %Surface area exposed to laminar flow
    SbCr = S*(lCr/l);
    
    %Laminar drag in laminar region
    %(Extended Frankl-Voishel applied to Blasius)
    CdfLam = 1.328/sqrt(ReCr)*(1+0.17*M^2)^-0.1295;
    
    ReData = 10.^[2:0.1:12];
    [~,indexReCr] = min(abs(ReCr-ReData));
    [~,indexReL] = min(abs(ReL-ReData));
    MData = [0:0.2:1,2:1:10];
    [~,indexM] = min(abs(M-MData));
    load('CdfTrbData');
    %Turbulent drag from prepared data solving the Schofield implicit equation 
    %over a gridded range of Mach and Reynolds numbers.
    CdfTrbCr = CdfTrbData(indexReCr,indexM);
    CdfTrbL = CdfTrbData(indexReL,indexM);

    %Friction drag is the sum of the drag in the laminar non-seperated region,
    %the turbulent drag over the entire body length.
    Cdf = CdfLam*(SbCr/Sref)+CdfTrbL*(S/Sref)+CdfTrbCr*(SbCr/Sref); 