function [db,ds,sigma,lb,ln,lf,la,Sb,Ss,Sp,Vb,Xp,Xcg,noseType] = bodyGeometry(vehicle,cRoot)
%--------------------------------------------------------------------------
% bodyGeometry(vehicle,cRoot)
% BODY GEOMETRY ALLOCATOR
% Generates body geometry from user inputs or from preassigned vehicle model
%--------------------------------------------------------------------------    

vehicleType = deal(vehicle{1});

if vehicleType == "Custom"
    disp('Choose wing profile')
    db = input('Input body diameter (m): ');
    ln = input('Input nose length (m): ');
    lf = input('Input forebody length (m): ');
    la = input('Input afterbody length (m): ');
    
    disp('Choose nose type')
    disp('1: cone')
    disp('2: ogive')
    disp('3: blunted cone')
    noseType = input('Input: ');
    
    ds = disp('Input spherical diameter (m): ');
    
    disp('Enter the centre of gravity location (m), measured from the nose.')
    disp(['Can assume to be at half the body length: ',num2str(lb/2),'m'])
    Xcg = input('Input: ');    
else
    [db,ln,lf,la,noseType,ds,Xcg] = deal(vehicle{6:12});
end

%Body cross sectional area
Sb = pi/4*db^2;
%Total vehicle length
lb = ln+lf+cRoot+la;
%Body surface area
Ss = pi*db*lb;
%Body planform area
SpBody = db*(lb-ln);
%Body centroid
XcBody = (lb-ln)/2;

if noseType == 1
    noseType = "cone";
    %Nose cone angle
    sigma = atan(db/(2*ln)); 
    %Nose blunting diameter
    ds = 0;
    %Calculate nose and body surface area
    Ss = pi*db/2*(db/2+sqrt(ln^2+(db/2)^2))+pi*db*(lb-ln);
    %Calculate nose planform area    
    SpNose = ln*db/2;
    %Calculate nose centroid        
    XcNose = 3/4*ln;
    %Calculate vehicle planform area
    Sp = SpNose+SpBody;
    %Calculate vehicle centroid    
    Xp = (SpNose*XcNose+SpBody*XcBody)/Sp;
    %Calculate vehicle volume        
    Vb = pi*(db/2)^2*(ln/3)+Sb*(lb-ln);
elseif noseType == 2
    noseType = "ogive";    
    %Nose cone angle
    sigma = atan(db/(2*ln)); 
    %Nose blunting diameter
    ds = 0;    
    
    R = (ln/db)^2+0.25;
    %Calculate nose and body surface area
    Ss = db^2*(2*pi*R*((R-0.5)*asin(-ln/(R*db))+ln/db))+pi*db*(lb-ln);
    %Calculate nose planform area        
    SpNose = db^2*(ln/db*sqrt(R^2-(ln/db)^2)+R^2*asin(ln/(db*R))-2*(ln/db)*(R-1/2));
    %Calculate nose centroid        
    XcNose = db*(ln/db-((2/3)*(R^3-(R^2-(ln/db)^2)^(3/2))-(ln/db)^2*(R-0.5)/(SpNose/db^2)));
    %Calculate vehicle planform area 
    Sp = SpNose+SpBody;
    %Calculate vehicle centroid        
    Xp = (SpNose*XcNose+SpBody*XcBody)/Sp;
    %Calculate vehicle volume        
    Vb = db^3*(pi*((2/3)*(ln/db)^3-(SpNose/(db^2))*(R-1/2)))+Sb*(lb-ln);
elseif noseType == 3
    noseType = "blunt";
    sigma = 0.5; 
    %Planform area, surface area, etc for vehicle only, not including nose length.
end