function CdpB = HypCdpB(sigma,ln,ds,noseType)
%--------------------------------------------------------------------------
% HypCdpB(sigma,ln,ds,noseType)
% SUPERSONIC PRESSURE DRAG COEFFICIENT
% Calculates the supersonic low angle of attack lift coeffient for the
% vehicle body.
%--------------------------------------------------------------------------
if noseType == "cone" || noseType == "ogive" 
    sigmaData = ones(1,6).*[0;10;20;40;60;80;90];
    aTodData = [0,0.2,0.4,0.6,0.8,1].*ones(7,1);

    CdpBconeData = [0,0,0,0,0,0;
    0.069,0.050,0.037,0.013,0.018,0.000;
    0.235,0.226,0.198,0.129,0.078,0.000;
    0.836,0.785,0.697,0.521,0.299,0.000;
    1.474,1.432,1.265,0.955,0.534,0.000;
    1.950,1.857,1.630,1.232,0.704,0.000;
    2.000,1.921,1.676,1.278,0.718,0.000];

    %Interpolated data for a conical or ogive nose
    F = griddedInterpolant(sigmaData,aTodData,CdpBconeData);
    CdpB = F(sigma*180/pi,0);
elseif noseType == "blunt"  
    CdpBbluntData = [0.00, 2.00
    0.20, 1.63
    0.40, 1.35
    0.60, 1.15
    0.80, 1.04
    1.00, 1.00
    10, 1.00];

    %Interpolated data for a conical or ogive nose
    F = griddedInterpolant(CdpBbluntData(:,1),CdpBbluntData(:,2));
    CdpB = F(2*ln/ds);
end
