function ClB = HypClB(ln,db,ds,alpha,noseType)
%--------------------------------------------------------------------------
% HypClB(ln,db,ds,alpha,noseType)
% HYPERSONIC BODY LIFT COEFFICIENT
% Calculates the hypersonic low angle of attack lift coeffient for the
% vehicle body.
%--------------------------------------------------------------------------
if noseType == "blunt"
    CnDataSphere = [0.00, 0.00
    0.20, 0.36
    0.40, 0.64
    0.60, 0.82
    0.80, 0.95
    1.00, 1.00];

    %Interpolating normal coefficent lift slope data for blunt nose.
    F = griddedInterpolant(CnDataSphere(:,1),CnDataSphere(:,2));
    CnAlpha = F(2*ln/ds);
elseif noseType == "cone"
    fNData = [1;1.5;2;3;4;5;6;7];
    dsData = [0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8];

    CnData = [1.62,1.68,1.69,1.68,1.64,1.59,1.53,1.45,1.34;
    1.81,1.83,1.82,1.79,1.75,1.69,1.60,1.49,1.35;
    1.89,1.89,1.88,1.85,1.80,1.72,1.62,1.50,1.36;
    1.95,1.95,1.93,1.89,1.82,1.74,1.63,1.51,1.36;
    1.97,1.97,1.94,1.90,1.83,1.74,1.64,1.51,1.36;
    1.99,1.98,1.95,1.90,1.83,1.75,1.65,1.51,1.36;
    1.99,1.98,1.95,1.91,1.83,1.75,1.64,1.52,1.36;
    1.98,1.98,1.95,1.91,1.84,1.75,1.65,1.51,1.36];

    %Double interpolation for normal coefficent lift slope data for conical nose.
    for index = 1:1:9
        F = griddedInterpolant(fNData',CnData(:,index));
        Cn(index) = F(ln/db);
    end
    F = griddedInterpolant(dsData,Cn);
    CnAlpha = F(ds/db);
elseif noseType == "ogive"
    fNData = [1;1.5;2;3;4;5;6;7];
    dsData = [0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8];

    CnData = [1.58,1.58,1.57,1.56,1.54,1.51,1.47,1.40,1.31;
    1.75,1.74,1.74,1.72,1.69,1.63,1.55,1.45,1.32;
    1.83,1.84,1.82,1.79,1.75,1.68,1.59,1.48,1.33;
    1.91,1.91,1.89,1.85,1.79,1.71,1.62,1.50,1.35;
    1.95,1.93,1.91,1.87,1.81,1.73,1.62,1.50,1.36;
    1.96,1.95,1.93,1.89,1.82,1.74,1.63,1.51,1.37;
    1.97,1.96,1.94,1.89,1.83,1.74,1.64,1.51,1.37;
    1.98,1.97,1.94,1.90,1.83,1.75,1.64,1.51,1.37];

    %Double interpolation for normal coefficent lift slope data for ogive nose.
    for index = 1:1:9
        F = griddedInterpolant(fNData',CnData(:,index));
        Cn(index) = F(ln/db);
    end
    F = griddedInterpolant(dsData,Cn);
    CnAlpha = F(ds/db);
end

%Lift coefficient assuming small angle approx.
ClB = CnAlpha*alpha; 

