function CmCGB = HypCmB(ClB,alpha,lb,ln,db,ds,sigma,Xcg,noseType)
%--------------------------------------------------------------------------
% HypCmB(ClB,alpha,lb,ln,db,ds,sigma,Xcg,noseType)
% HYPERSONIC BODY MOMENT COEFFICIENT
% Calculates the hypersonic low angle of attack moment coeffient for the
% vehicle body.
%-------------------------------------------------------------------------
if noseType == "blunt"
    CmAlphaData = [0.00, 0.00
    0.05, -0.16
    0.15, -0.27
    0.30, -0.37
    0.45, -0.42
    0.61, -0.47
    0.75, -0.49
    1.00, -0.51];

    %Interpolating moment curve slope data for blunt nose.
    F = griddedInterpolant(CmAlphaData(:,1),CmAlphaData(:,2));
    CmAlpha = F(2*ln/ds);
    CmCGB = CmAlpha*alpha;
elseif noseType == "cone"
    XcponlnData =[0.67,0.64,0.61,0.59,0.56,0.52,0.48,0.43,0.36;
    0.67,0.64,0.61,0.58,0.55,0.51,0.46,0.41,0.33;
    0.67,0.64,0.61,0.58,0.54,0.50,0.45,0.40,0.32;
    0.66,0.64,0.61,0.57,0.54,0.50,0.45,0.39,0.31;
    0.66,0.63,0.60,0.57,0.53,0.49,0.44,0.39,0.30;
    0.66,0.63,0.60,0.57,0.53,0.49,0.44,0.38,0.30;
    0.66,0.63,0.60,0.57,0.53,0.49,0.44,0.38,0.30;
    0.66,0.63,0.60,0.57,0.53,0.49,0.44,0.38,0.29];

    %Interpolating center of pressure data for conical nose.
    for index = 1:1:9
        F = griddedInterpolant([2,3,4,5,6,7,8,9]',XcponlnData(:,index));
        Xcponln(index) = F(ln/db);
    end
    F = griddedInterpolant([0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8],Xcponln);
    Xcp(index) = ln*F(ds/db);
    
    %Calculating pitching moment of body about CG from center of pressure 
    %location and net body lift force.
    CmCGB = (Xcg/lb-Xcp/lb)*ClB;
elseif noseType == "ogive"    
    XcponlnData =[0.50,0.49,0.47,0.46,0.45,0.43,0.42,0.40,0.37;
    0.47,0.46,0.44,0.42,0.40,0.38,0.36,0.32,0.28;
    0.47,0.45,0.43,0.41,0.39,0.37,0.34,0.30,0.26;
    0.47,0.45,0.43,0.41,0.39,0.36,0.33,0.29,0.24;
    0.47,0.45,0.43,0.40,0.38,0.36,0.32,0.28,0.23;
    0.47,0.44,0.42,0.40,0.38,0.35,0.32,0.28,0.22;
    0.47,0.44,0.42,0.40,0.37,0.35,0.31,0.27,0.22;
    0.46,0.44,0.42,0.40,0.37,0.34,0.31,0.27,0.21;
    0.46,0.44,0.42,0.39,0.37,0.34,0.31,0.26,0.21];

    %Interpolating center of pressure data for ogive nose.
    for index = 1:1:9
        F = griddedInterpolant([1,2,3,4,5,6,7,8,9]',XcponlnData(:,index));
        Xcponln(index) = F(ln/db);
    end
    F = griddedInterpolant([0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8],Xcponln);
    Xcp = ln*F(ds/db);
    
    %Calculating pitching moment of body about CG from center of pressure 
    %location and net body lift force.
    CmCGB = (Xcg/lb-Xcp/lb)*ClB;
end