function [CmCGB,CmPot,CmVsc] = SprCmB(M,alpha,lb,Ss,Sp,Vb,Xcg,Xp)
%--------------------------------------------------------------------------
% SprCmB(M,alpha,lb,Ss,Sp,Vb,Xcg,Xp)
% SUPERSONIC BODY MOMENT COEFFICIENT
% Calculates the supersonic low angle of attack moment coeffient for the
% vehicle body.
%--------------------------------------------------------------------------
    lref = lb;
    Sref = Ss;
    
    CdcData = [0.00, 1.21
    0.20, 1.20
    0.40, 1.26
    0.60, 1.49
    0.80, 1.77
    1.00, 1.79
    1.43, 1.56
    2, 1.41
    2.85, 1.33
    4, 1.30
    5, 1.28
    6.67, 1.27
    8.33, 1.26
    10, 1.26
    20, 1.26];   
    %Interpolating for cross flow drag coefficent based on cross flow Mach
    %number.
    F = griddedInterpolant(CdcData(:,1),CdcData(:,2));
    Cdc = F(M*sin(alpha));
         
    %Correcting for sign of viscous moment component

    if alpha > 0
        signVsc = 1;
    else 
        signVsc = -1;
    end
    
    CmPot = 2*alpha*(Vb/(Sref*lref)-(1-Xcg/lref));
    CmVsc = signVsc*Cdc*(Sp/Sref)*((Xcg-Xp)/lref)*alpha^2;
    
    %Total moment coefficent.
    CmCGB = CmPot+CmVsc;
 