function ClB = SubClB(M,alpha,lb,db,Sb)
%--------------------------------------------------------------------------
% SubClB(M,alpha,lb,db,Sb)
% SUBSONIC BODY LIFT COEFFICIENT
% Calculates the subsonic low angle of attack lift coeffient for the
% vehicle body.
%--------------------------------------------------------------------------

    k2minusk1Data = [4, 0.78;
    8, 0.92;
    12, 0.96;
    16, 0.98;
    20, 0.99];

    %Interpolating for mass motion factor.
    F = griddedInterpolant(k2minusk1Data(:,1),k2minusk1Data(:,2));
    k2minusk1 = F(lb/db);
    
    etaData = [2.01, 0.12
    4.01, 0.20
    8.12, 0.33
    12.11, 0.41
    20.04, 0.52
    28.08, 0.58
    32.01, 0.58];

    %Interpolating for 3D cross flow correction factor.
    F = griddedInterpolant(etaData(:,1),etaData(:,2));
    eta = F(lb/db);
    
    CdcData = [0.00, 1.20
    0.20, 1.20
    0.40, 1.26
    0.60, 1.49
    0.80, 1.77
    1.00, 1.79
    1.43, 1.56
    2, 1.41
    2.85, 1.33
    4, 1.30
    5, 0.28
    6.67, 1.27
    8.33, 1.26
    10, 1.26
    20, 1.26];

    %Interpolating for cross flow drag coefficent based on cross flow Mach
    %number.
    F = griddedInterpolant(CdcData(:,1),CdcData(:,2));
    Cdc = F(M*sin(abs(alpha)));
    
    %Calculating coefficient and correcting for sign of viscous lift component.    
    if alpha > 0
    ClB = k2minusk1*2*alpha*Sb/(pi/4*db^2*lb)^(2/3)+(alpha^2*eta*Cdc*db*lb)/(pi/4*db^2*lb)^(2/3);
    else
    ClB = k2minusk1*2*alpha*Sb/(pi/4*db^2*lb)^(2/3)-(alpha^2*eta*Cdc*db*lb)/(pi/4*db^2*lb)^(2/3);
    end
