function [ClF,ClDelta] = SprClF(M,k,phiTE,sweepTE,delta,Sw,bf,cf)
%--------------------------------------------------------------------------
% SprClF(M,k,phiTE,sweepTE,delta,Sw,bf,cf)
% SUPERSONIC FLAP LIFT
% Calculates the supersonic low angle of attack flap lift contribution.
%--------------------------------------------------------------------------    
    %Flap area and compressibility factor    
    Sf = 2*bf*cf;
    beta = sqrt(M^2-1);

    %Busemann coefficients
    C1 = 2/beta;
    C2 = ((k+1)*M^4-4*(M^2-1))/(2*(M^2-1))^2;

    ClDeltaCorData = [-2,0.32;
    -0.98, 0.32;
    -0.95, 0.22;
    -0.90, 0.16;
    -0.80, 0.12;
    -0.60, 0.09;
    -0.20, 0.07;
    0.20, 0.07;
    0.60, 0.09;
    0.80, 0.12;
    0.90, 0.16;
    0.95, 0.22;
    0.98, 0.32;
    2,0.32];

    %Interpolating data for supersonic lift effectiveness
    %NOTE: assuming flaps always in-board from the wing tips
    F = griddedInterpolant(ClDeltaCorData(:,1),ClDeltaCorData(:,2));
    ClDeltaCor = (180/pi)*(1/beta)*F(tan(sweepTE)/beta);
    
    ClDelta = (1-(C2/C1)*(phiTE))*ClDeltaCor*(Sf/Sw);  %/rad
    
    %Total flap lift 
    ClF = ClDelta*delta; 