function CmCGF = SprCmF(M,k,ln,lf,phiTE,bw,bf,bFlapI,sweepTE,cMAC,cRoot,cf,delta,Sw,Xcg)
%--------------------------------------------------------------------------
% SprCmF(M,k,ln,lf,phiTE,bw,bf,bFlapI,sweepTE,cMAC,cRoot,cf,delta,Sw,Xcg)
% SUPERSONIC FLAP MOMENT
% Calculates the supersonic low angle of attack flap moment contribution.
%--------------------------------------------------------------------------    
    %Total flap area
    Sf = 2*bf*cf;
    beta = sqrt(M^2-1);
    
    %Busemann coefficients
    C1 = 2/beta;
    C2 = ((k+1)*M^4-4*(M^2-1))/(2*(M^2-1)^2);

    %Correction factors 
    K1 = (1-(C2/C1)*phiTE)*(3);
    K2 = (1-(C2/C1)*phiTE)*(tan(sweepTE));
    K3 = (1-(C2/C1)*phiTE);

    
    %Finding lift effectiveness by dividing Cl by delta with treatment for the
    %singularity at delta = 0.
    if delta == 0
        ClFU = SprClF(M,k,phiTE,sweepTE,pi/180,Sw,bf,cf);
        ClF = 0.5*(ClFU);
        
        ClDelta = ClF/(pi/180);
    else
        ClF = SprClF(M,k,phiTE,sweepTE,delta,Sw,bf,cf);
        ClDelta = ClF/delta;
    end

    %Finding roll effectiveness
    CrollDelta = SprCrollDelta(ClDelta,M,k,phiTE,cf,bw,bf,bFlapI,sweepTE,Sf,Sw); %/rad

    CmDelta0Data = [0.00, -0.04;
    0.20, -0.04;
    0.40, -0.04;
    0.60, -0.05;
    0.80, -0.06];
    %Interpolating for moment effectiveness
    F = griddedInterpolant(CmDelta0Data(:,1),CmDelta0Data(:,2)); %/rad
    CmDelta0 = (180/pi)*(1/beta)*F(tan(sweepTE)/beta);

    %NOTE: xf is the distance of the leading edge of the control root chord behind the wing axis of pitch
    Xf = Xcg-(ln+lf+cRoot)+cf;

    %Calculating the moment    
    CmDelta = K1*(1/3)*(bf/cMAC)*(cf/Sw)*CmDelta0-K2*(1/2)*(bf/cMAC)*(Sf/Sw)*CrollDelta-K3*(Xf/cMAC)*(Sf/Sw)*ClDelta; %/rad
    CmCGF = CmDelta*delta;