function Cd = CdHighAlpha(CdB0,CdW0,M,alpha,lb,db,Sw,Sref)
%--------------------------------------------------------------------------
% CdHighAlpha(CdB0,CdW0,M,alpha,lb,db,Sw,Sref)
% VEHICLE HIGH ALPHA DRAG COEFFICIENT
% Calculates the high angle of attack vehicle drag coefficient.
%--------------------------------------------------------------------------
    %Drag does not depend on sign of alpha
    alpha = abs(alpha);
    %Calculating planform area, base area
    Sb = pi/4*db^2;
    Sp = lb*db;

    k2minusk1Data = [4, 0.78;
    8, 0.92;
    12, 0.96;
    16, 0.98;
    20, 0.99;
    30, 0.99];
    %Interpolating for mass motion factor.
    k2minusk1 = interp1(k2minusk1Data(:,1),k2minusk1Data(:,2),lb/db,'linear','extrap');

    etaData = [1, 0.53;
    8, 0.68;
    12, 0.71;
    16, 0.73;
    20, 0.75;
    30, 0.8];
    %Interpolating for 3D cross flow correction factor.    
    eta = interp1(etaData(:,1),etaData(:,2),lb/db,'linear','extrap');

    CdcData = [0.00, 1.20
    0.40, 1.21
    0.60, 1.46
    0.80, 1.83
    1.00, 1.81
    1.40, 1.52
    1.80, 1.36
    2.20, 1.30
    3.00, 1.29];
    %Interpolating for cross flow cylinder drag coefficent based on cross flow Mach
    %number.
    CdcB = interp1(CdcData(:,1),CdcData(:,2),M*sin(alpha),'linear','extrap');

    %Body drag coefficient.
    delCdB = k2minusk1*(Sb/Sref)*(sin(alpha))^2+eta*CdcB*(Sp/Sref)*(sin(alpha))^3;
    CdB = CdB0*cos(alpha)+delCdB; 

    CdFPData = [0, 1.17
    0.30, 1.16
    0.57, 1.22
    0.80, 1.36
    0.91, 1.59
    0.98, 1.68
    1.02, 1.68
    1.08, 1.61
    1.16, 1.36
    1.35, 1.20
    1.82, 1.03
    2.56, 0.89
    3.29, 0.86
    4.00, 0.87
    10.00, 0.87];
    %Interpolating for lift as flat plate drag cofficient.
    CdFP = interp1(CdFPData(:,1),CdFPData(:,2),M,'linear','extrap');
    delCdW = CdFP*(Sw/Sref)*sin(alpha);
    %Wing drag coefficient.
    CdW = CdW0*cos(alpha)+delCdW;

    %Vehicle drag coefficient.
    Cd = CdW+CdB;
