function [ClV,ClW,ClB,ClWBAlpha,ClBWAlpha,ClWBDelta,ClBWDelta] = ClHighAlpha(CdB0,ClAlpha,M,Mcr,alpha,bw,AR,taper,sweepLE,lb,db,Sw,Sref,delta,Kwb,Kbw)
%--------------------------------------------------------------------------
% ClHighAlpha(CdB0,ClAlpha,M,Mcr,alpha,bw,AR,taper,sweepLE,lb,db,Sw,Sref,delta,Kwb,Kbw)
% VEHICLE HIGH ALPHA LIFT COEFFICIENT
% Calculates the high angle of attack vehicle lift coefficient.
%--------------------------------------------------------------------------
    %Calculating planform area, base area
    Sb = pi/4*db^2; 
    Sp = lb*db;

    %Compressibility factor 
    if M < 0.99
        beta = sqrt(1-M^2);
    elseif M > 1.01
        beta = sqrt(M^2-1);
    elseif M >= 0.99 && M <= 1.01
        beta = 0.5*(sqrt(1.01^2-1)+sqrt(1-0.99^2));
    end

    k2minusk1Data = [4, 0.78;
    8, 0.92;
    12, 0.96;
    16, 0.98;
    20, 0.99;
    30, 0.99];
    %Interpolating for mass motion factor.
    k2minusk1 = interp1(k2minusk1Data(:,1),k2minusk1Data(:,2),lb/db,'linear','extrap');

    etaData = [1, 0.53;
    8, 0.68;
    12, 0.71;
    16, 0.73;
    20, 0.75;
    30, 0.8];
    %Interpolating for 3D cross flow correction factor.    
    eta = interp1(etaData(:,1),etaData(:,2),lb/db,'linear','extrap');

    CdcData = [0.00, 1.20
    0.40, 1.21
    0.60, 1.46
    0.80, 1.83
    1.00, 1.81
    1.40, 1.52
    1.80, 1.36
    2.20, 1.30
    3.00, 1.29];
    %Interpolating for cross flow cylinder drag coefficent based on cross flow Mach
    %number.
    CdcB = interp1(CdcData(:,1),CdcData(:,2),M*sin(alpha),'linear','extrap');

    if alpha > 0 
    ClB = k2minusk1*(Sb/Sref)*sin(2*alpha)*cos(alpha/2)+eta*CdcB*(Sp/Sref)*cos(alpha)*(sin(alpha))^2;%-CdB0*(cos(alpha))^2*sin(alpha);
    else
    ClB = k2minusk1*(Sb/Sref)*sin(2*alpha)*cos(alpha/2)-eta*CdcB*(Sp/Sref)*cos(alpha)*(sin(alpha))^2;%-CdB0*(cos(alpha))^2*sin(alpha);
    end

    %Supersonic Kwb data.
    Kwb2Data = [0.00, 1.01
    0.20, 0.95
    0.40, 0.94
    0.60, 0.93
    0.80, 0.96
    0.99, 0.99];
    Kwb2 = interp1(Kwb2Data(:,1),Kwb2Data(:,2),db/bw,'linear','extrap');
    Kbw2 = db/bw;

    %If the vehicle is supersonic...
    if M > Mcr
        %... and the wing type is delta ...
        if tan(sweepLE) == (4/AR)*((1-taper)/(1+taper)) 
            %... supersonic effects apply for these conditions.
            test1 = beta*AR*(1+taper)*(tan(sweepLE)/beta+1);
            test2 = 4;
        %... and the wing type is not ...
        else
            %... supersonic effects apply for these conditions.        
            test1 = beta*AR;
            test2 = 1;
        end

        if test1 > test2 
            %If supersonic effects do not apply...
            %... find Kbw from the subsonic data.     
            Kbw2 = Kbw;
        end
    end

    %Finding lift contributions due to interference effects.     
    ClWBAlpha = Kwb*(Sw/Sref)*ClAlpha*(sin(alpha))*(cos(alpha));
    ClBWAlpha = Kbw*(Sw/Sref)*ClAlpha*(sin(alpha))*(cos(alpha));
    ClWBDelta = Kwb2*(Sw/Sref)*ClAlpha*(sin(delta))*(cos(alpha+delta));
    ClBWDelta = Kbw2*(Sw/Sref)*ClAlpha*(sin(delta))*(cos(alpha+delta));

    CdcWData = [2.01,3.97,5.99;
    1.30,2.44,3.57;
    0.91,1.73,2.44;
    0.68,1.05,1.87];
    for index = 1:1:3
        F = griddedInterpolant([0,1,2,3]',CdcWData(:,index));
        CdcW(index) = F(AR);
    end
    %Interpolating for wing crossflow drag coefficient.     
    F = griddedInterpolant([0,0.5,1],CdcW);
    CdcW = F(taper);
    %Calculating lift alone coefficient    
    ClW = (Sw/Sref)*CdcW*(sin(alpha+delta))^2*cos(alpha+delta);

    %Total vehicle lift    
    ClV = ClWBAlpha+ClBWAlpha+ClWBDelta+ClBWDelta+ClW+ClB;