function [CmCG,CmB,CmW,XcpW] = CmHighAlpha(ClW,ClWBAlpha,ClBWAlpha,ClWBDelta,ClBWDelta,M,alpha,cRoot,bw,AR,taper,sweepLE,lb,ln,lf,db,Vb,Sref,Sw,Xcg,Xp) 
%--------------------------------------------------------------------------
% CmHighAlpha(ClW,ClWBAlpha,ClBWAlpha,ClWBDelta,ClBWDelta,M,alpha,cRoot,bw,AR,taper,sweepLE,lb,ln,lf,db,Vb,Sref,Sw,Xcg,Xp)
% VEHICLE HIGH ALPHA MOMENT COEFFICIENT
% Calculates the high angle of attack vehicle moment coefficient.
%--------------------------------------------------------------------------
    %Calculating planform area, base area
    Sb = pi/4*db^2;
    Sp = db*lb;
    lref = lb;

    k2minusk1Data = [4, 0.78;
    8, 0.92;
    12, 0.96;
    16, 0.98;
    20, 0.99;
    30, 0.99];
    %Interpolating for mass motion factor.
    k2minusk1 = interp1(k2minusk1Data(:,1),k2minusk1Data(:,2),lb/db,'linear','extrap');

    etaData = [1, 0.53;
    8, 0.68;
    12, 0.71;
    16, 0.73;
    20, 0.75;
    30, 0.8];
    %Interpolating for 3D cross flow correction factor.    
    eta = interp1(etaData(:,1),etaData(:,2),lb/db,'linear','extrap');

    CdcData = [0.00, 1.20
    0.40, 1.21
    0.60, 1.46
    0.80, 1.83
    1.00, 1.81
    1.40, 1.52
    1.80, 1.36
    2.20, 1.30
    3.00, 1.29];
    %Interpolating for cross flow clyinder drag coefficent based on cross flow Mach
    %number.
    CdcB = interp1(CdcData(:,1),CdcData(:,2),M*sin(alpha),'linear','extrap');

    %Wing body alone moment coefficient from potential and viscous contributions. 
    CmB = k2minusk1*((Vb-Sb*(lb-Xcg))/(Sref*lref))*sin(2*alpha)*cos(alpha/2)+eta*CdcB*(Sp/Sref)*((Xcg-Xp)/lref)*(sin(alpha))^2;

    CdFPData = [0, 1.17
    0.30, 1.16
    0.57, 1.22
    0.80, 1.36
    0.91, 1.59
    0.98, 1.68
    1.02, 1.68
    1.08, 1.61
    1.16, 1.36
    1.35, 1.20
    1.82, 1.03
    2.56, 0.89
    3.29, 0.86
    4.00, 0.87
    10.00, 0.87];
    %Interpolating for wing as flat plate drag coefficient. 
    CdFP = interp1(CdFPData(:,1),CdFPData(:,2),M,'linear','extrap');
    delCdW = CdFP*(Sw/Sref)*sin(alpha);

    %Finding centre of pressure shift due to wing on body and body on wing effects. 
    [XcpWB,XcpBW] = XcpHighAlpha(M,db,ln,lf,cRoot,bw,AR,taper,sweepLE);

    %Total wing moment including wing-body and flap deflection lift contributions. 
    CmW = ((ClWBAlpha+ClW)*cos(alpha)+delCdW*(sin(alpha)))*(XcpWB/lref)+((ClBWAlpha*cos(alpha)+ClBWDelta))*(XcpBW/lref);

    %Wing centre of pressure location including wing-body and flap deflection 
    %lift contributions. 
    XcpW = CmW*lref/((ClWBAlpha+ClBWAlpha+ClW)*cos(alpha)+ClWBDelta+ClBWDelta+(delCdW)*sin(alpha));

    %Total moment of body refered to centre of gravity. 
    CmCG = CmB+CmW*((Xcg-XcpW)/XcpW);