function [Kwb,Kbw,Kn] = KwbFactors(M,Mcr,ClAlpha,db,bw,la,cRoot,AR,taper,sweepLE,Sb,Sw)    
%--------------------------------------------------------------------------
% KwbFactors(M,Mcr,ClAlpha,db,bw,la,cRoot,AR,taper,sweepLE,Sb,Sw)  
% WING-BODY AND BODY-WING LIFT CARRY-OVER INTERFERENCE FACTORS
% Calculates the interference effect from the wing lift carry over onto the
% body, the body lift carry over onto the wing and the nose upwash.
%--------------------------------------------------------------------------
    if M>1 
        beta = sqrt(M^2-1);
    else
        beta = sqrt(1-M^2);
    end
    
    %Data for the wing effect on body.
    KwbData = [0.00,1.00;
    0.20,1.16;
    0.40,1.35;
    0.60,1.56;
    0.80,1.77;
    1.00,1.99];
    F = griddedInterpolant(KwbData(:,1),KwbData(:,2));
    Kwb = F(db/bw);

    %Data for the body effect on wing.
    KbwData0 = [0.00,0.00;
    0.20,0.29;
    0.40,0.61;
    0.60,1.00;
    0.80,1.43;
    1.00,1.99];

    %Data for the body effect on wing modified to account for supersonic
    %effects.
    KbwData1 = [0,0.89,1.79,2.51,3.06,3.63,4.50,5.22,6.16;
    0,0.52,1.07,1.54,1.77,2.13,2.88,3.26,3.87;
    0,0.24,0.54,0.75,0.88,1.11,1.37,1.56,1.90;
    0,0.17,0.34,0.45,0.58,0.73,0.87,1.04,1.21;
    0,0.15,0.28,0.34,0.45,0.51,0.64,0.76,0.91;
    0,0.10,0.23,0.25,0.36,0.38,0.53,0.63,0.74;
    0,0.10,0.23,0.25,0.36,0.38,0.53,0.63,0.74];
  
    %If the vehicle is subsonic...
    if M <= Mcr
        %... use the subsonic data.
        KbwData = KbwData0;
        F = griddedInterpolant(KbwData(:,1),KbwData(:,2));
        Kbw = F(db/bw);
    %If the vehicle is supersonic...
    elseif M > Mcr
        %... and the wing type is delta ...
        if tan(sweepLE) == (4/AR)*((1-taper)/(1+taper)) 
           %... supersonic effects apply for these conditions.
            test1 = beta*AR*(1+taper)*(tan(sweepLE)/beta+1);
            test2 = 4;
        %... and the wing type is not ...        
        else
            %... supersonic effects apply for these conditions.
            test1 = beta*AR;
            test2 = 1;
        end
        %If supersonic effects do not apply...
        if test1 <= test2        
            %... find Kbw from the subsonic data.
            KbwData = KbwData0;
            F = griddedInterpolant(KbwData(:,1),KbwData(:,2));
            Kbw = F(db/bw);        
        else
            %... find Kbw from the supersonic data.
            KbwData = KbwData1;
            doncData = ones(1,9).*[0.20;0.60;1.40;2.20;3.00;3.80;10^5];
            sweepData = [0,0.2,0.4,0.6,0.8,1,2,4,10^7].*ones(7,1);
            F = griddedInterpolant(doncData,sweepData,KbwData);
            Kbw = 1/((beta*ClAlpha)*(taper+1)*(bw/db-1))*F((beta*db)/cRoot,beta*(cot(abs(sweepLE)+0.000001)));
        end
    end
    
    %Data for the nose effect.
    ClAlphaN = 2; %Assuming slender body theory    
    Kn = (ClAlphaN*Sb)/(ClAlpha*Sw);