function XacV = SprXacV(XacW,ClAlpha,M,ln,lf,la,db,cRoot,AR,taper,sweepLE,Sw,Kwb,Kbw,noseType)
%--------------------------------------------------------------------------
% SprXacV(XacW,ClAlpha,M,ln,lf,la,db,cRoot,AR,taper,sweepLE,Sw,Kwb,Kbw,noseType)
% SUPERSONIC WING BODY AERODYNAMIC CENTRE
% Calculates the supersonic, low angle of attack wingbody aerodynamic centre 
% by considering the interference effect of the body on the wing, the wing 
% on the body, and the wing alone's aerodynamic centre.
%--------------------------------------------------------------------------
    beta = sqrt(M^2-1);
    fN = ln/db;
    fA = (lf+la+cRoot)/db;
    
    % Finding the modified lift curve slopes from the wing interference parameter
    % Kwb, the body interference parameter Kbw, and the effect on the nose.            
    ClAlphaWB = Kwb*ClAlpha;
    ClAlphaBW = Kbw*ClAlpha;
    ClAlphaN = 2*((pi*db^2)/(4*Sw));
        
    % Finding the shifted aerodynamic centre slopes from the wing interference
    % effect and the body interference parameter effect.
    XWB = (XacW-(ln+lf))/cRoot;
    
    F = griddedInterpolant([0,0.2,0.6,1,2.8],[0.5,0.58,0.65,0.67,0.67]);
    XBW = F(db*beta/cRoot);
        
    % For low aspect ratio wings, different experimental data is used.    
    if beta*AR*(1+taper)*(1+(1)/(beta*cot(sweepLE))) <= 4
        F = griddedInterpolant([0,1,2],[0,0.5,0.5]);
        XBW1 = F((1/4)*(AR*(1+taper)*tan(sweepLE)));
        XBW = interp1([0,4],[XBW1,XBW],beta*AR*(1+taper)*(1+(1)/(beta*cot(sweepLE))),'linear','extrap');
    end
    
    % Finding the CP location from the effect of the nose.     
    if noseType == "ogive"
        betaonfN = [0.4;1;1.4;10].*ones(1,7);
        fAonfNdata = [0,0.4,0.8,1.2,1.6,2,10^9];
        xCPonlnData = [0.54,0.42,0.35,0.29,0.24,0.21,0;
        0.53,0.45,0.40,0.36,0.32,0.28,0;
        0.51,0.46,0.42,0.38,0.35,0.33,0;
        0.51,0.46,0.42,0.38,0.35,0.33,0];
    elseif noseType == "cone" || noseType == "blunt"
        betaonfN = [0.19,0.19,0.21,0.50,0.78,0.87,0.90;
        0.49,0.50,0.50,0.80,0.90,0.97,0.98;
        1.00,1.00,1.00,1.00,1.00,1.00,1.00;
        1.40,1.40,1.40,1.40,1.40,1.40,1.40;
        5.00,5.00,5.00,5.00,5.00,5.00,5.00;
        10^9,10^9,10^9,10^9,10^9,10^9,10^9];
        fAonfNdata = [0,0.5,1,2,3,4,10^9];
        xCPonlnData = [0.67,0.49,0.37,0.26,0.20,0.14,0;
        0.67,0.55,0.41,0.32,0.22,0.16,0;
        0.67,0.55,0.47,0.35,0.24,0.16,0;
        0.67,0.54,0.47,0.39,0.29,0.22,0;
        0.67,0.49,0.41,0.40,0.36,0.35,0;
        0.67,0.47,0.38,0.40,0.39,0.36,0];
    end 
    for index = 1:1:7
        F = griddedInterpolant(betaonfN(:,index),xCPonlnData(:,index));
        xCPonln(index) = F(beta/(fN+0.001));
    end    
    F = griddedInterpolant(fAonfNdata,xCPonln);
    xCPonln = F(fA/(fN+0.001));
    
    % Correcting to the common reference.     
    XN = (ln/cRoot)*(xCPonln);
    
    % Calculating the vehicle aerodynamic centre by considering the weighted
    % average of each interference effect.       
    Xac0 = (XN*ClAlphaN+XWB*ClAlphaWB+XBW*ClAlphaBW)/(ClAlphaN+ClAlphaWB+ClAlphaBW);
    % Changing the reference to in m instead of root chords, and measured 
    % from the nose instead of the leading edge of the root chord.
    XacV = ln+lf+Xac0*cRoot;   
end