function XacV = SubXacV(XacW,ClAlpha,M,ln,lf,db,bw,cRoot,AR,taper,sweepLE,sweep25,Sw,Kwb,Kbw,noseType)
%--------------------------------------------------------------------------
% SubXacV(XacW,ClAlpha,M,ln,lf,db,bw,cRoot,AR,taper,sweepLE,sweep25,Sw,Kwb,Kbw,noseType)
% SUBSONIC WING BODY AERODYNAMIC CENTRE
% Calculates the subsonic, low angle of attack wingbody aerodynamic centre 
% by considering the interference effect of the body on the wing, the wing 
% on the body, and the wing alone's aerodynamic centre.
%--------------------------------------------------------------------------
    if M < 0.99
        beta = sqrt(1-M^2);
    end
    % Finding the modified lift curve slopes from the wing interference parameter
    % Kwb, the body interference parameter Kbw, and the effect on the nose.
    ClAlphaWB = Kwb*ClAlpha;
    ClAlphaBW = Kbw*ClAlpha;
    ClAlphaN = 2*((pi*db^2)/(4*Sw));
        
    % Finding the shifted aerodynamic centre slopes from the wing interference
    % effect and the body interference parameter effect.
    XWB = (XacW-(ln+lf))/cRoot;
    XBW = (1/4)*((bw-db)/(2*cRoot))*(tan(sweep25))*(-((db/bw)/(1-(db/bw)))+(sqrt(1-2*(db/bw))*log(((1-(db/bw))/(db/bw))+(1/(db/bw))*sqrt(1-2*(db/bw)))-(1-(db/bw))+(pi/2)*(db/bw))/((((db/bw)*(1-(db/bw)))/sqrt(1-2*(db/bw)))*log(((1-(db/bw))/(db/bw))+(1/(db/bw))*sqrt(1-2*(db/bw)))+((1-(db/bw))^2/(db/bw))-(pi/2)*(1-(db/bw))));

    % For low aspect ratio wings, the effect of the body interference on 
    % the wing is instead found from experimental data.
    if sqrt(1-M^2)*AR < 4
        F = griddedInterpolant([0,1,2],[0,0.5,0.5]);
        XBW1 = F((1/4)*(AR*(1+taper)*tan(sweepLE)));
        XBW2 = XBW;

        XBW = interp1([0,4],[XBW1,XBW2],beta*AR,'linear','extrap');
    end
    
    % Finding the equivalent nose length and fineness ratio to interpolate 
    % experimental data.
    fN = ln/db;
    fF = lf/db;
    
    fEq = fN+1.6*fF;
    lEq = fEq*db;
    
    if noseType == "cone" || noseType == "blunt" 
    % For a conical or blunted nose, the aerodynamic centre effect from nose 
    % downwash is to bring forward the aerodynamic centre by 0.33(lEq/cRoot).
        xonlEq = -0.33;
    elseif noseType == "ogive"
    % For a ogive nose, experimental data is used. 
        xonlEqData = [0.40, -2.66
        0.98, -0.57
        2.92, -0.54
        5.97, -0.53
        10.43, -0.53];
        %DATCOM pg.1066
        F = griddedInterpolant(xonlEqData(:,1),xonlEqData(:,2));
        xonlEq = F(fN);
    end
    XN = xonlEq*(lEq/cRoot);
    
    % Calculating the vehicle aerodynamic centre by considering the weighted
    % average of each interference effect.     
    Xac0 = (XN*ClAlphaN+XWB*ClAlphaWB+XBW*ClAlphaBW)/(ClAlphaN+ClAlphaWB+ClAlphaBW);
    % Changing the reference to in m instead of root chords, and measured 
    % from the nose instead of the leading edge of the root chord.
    XacV = ln+lf+Xac0*cRoot;
        