function [bw,bMAC,cMAC,cRoot,AR,taper,sweepLE,sweepTE,sweep25,Sw,tBar,ctMax,phiTE,airfoilAero,A2,B2,A3,xU,xL,Ucoeffs,Lcoeffs] = wingGeometry(vehicle)
%--------------------------------------------------------------------------
% wingGeometry(vehicle)
% WING GEOMETRY ALLOCATOR
% Generates wing geometry from user inputs or from preassigned vehicle model
%--------------------------------------------------------------------------    

vehicleType = deal(vehicle{1});
    
if vehicleType == "Custom"
    disp('Choose wing profile')

    bw = input('Input wing span (m): ');
    cRoot = input('Input wing root chord (m): ');
    cTip = input('Input wing tip chord (m): ');
    sweepLE = input('Input wing leading edge sweep (deg): ')*(pi/180);  
else
    [bw,sweepLE,cRoot,cTip] = deal(vehicle{2:5});
end

%Taper ratio
taper = cTip/cRoot;
%Wing area
Sw = bw*((cRoot*(taper+1))/2);
%Aspect ratio
AR = bw^2/Sw;
%Span location of mean aerodynamic chord
bMAC = (bw/6)*((1+2*taper)/(1+taper));
%Length of mean aerodynamic chord
cMAC = (2/3)*cRoot*((1+taper+taper^2)/(1+taper)); %MAC

%Sweep of 25% chord line
sweep25 = atan(tan(sweepLE)-(4/AR)*((25-0)/100)*((1-taper)/(1+taper))); %angle of quarter chord line
%Sweep of trailing edge
sweepTE = atan(tan(sweepLE)-(4/AR)*((100-0)/100)*((1-taper)/(1+taper)));

%Load airfoil coordinates from Javafoil
load('airfoilCoordsSym.mat');
airfoilCoords = airfoilCoordsSym;
coordMid = find(airfoilCoords(:,1)==0);

%Load airfoil curve fit coefficients, thickness and other properties
[Ucoeffs,Lcoeffs,tOfcU,tOfcL,tBar,ctMax,phiTE] = wingProfile(airfoilCoords,coordMid);

%Find coefficients for use in hypersonic analysis
syms c
A2 = double(int(diff(tOfcL)^2-diff(tOfcU,c)^2,c,0,1));
B2 = double(int(diff(tOfcL,c)^2+diff(tOfcU,c)^2,c,0,1));
A3 = double(int(diff(tOfcL,c)^3-diff(tOfcU,c)^3,c,0,1));

%Find location of camber tangiential to flow for use in hypersonic analysis
xU = double(solve(diff(tOfcU,c)==0,c));
xL = double(solve(diff(tOfcL,c)==0,c));

load('airfoilAeroSym.mat');
airfoilAero = airfoilAeroSym;