function CdpW = HypCdpW(k,alpha,xU,xL,Ucoeffs,Lcoeffs)
%--------------------------------------------------------------------------
% HypCmW(ClW,k,alpha,ln,lf,Xcg,xU,xL,Ucoeffs,Lcoeffs)
% HYPERSONIC WING PRESSURE DRAG COEFFICIENT
% Calculates the hypersonic low angle of attack pressure drag coeffient for the
% vehicle wing.
%--------------------------------------------------------------------------   
    %Coefficients used to parameterise the shape of the wing contour, upper
    %and lower curves. The pressure distribution is then calculated through
    %pU and pL.    
    [U1,U2,U3,U4,U5,U6,U7,U8,U9,~] = deal(Ucoeffs{:});
    pUbetaU = @(c) atan(9*U1*c.^8+8*U2*c.^7+7*U3*c.^6+6*U4*c.^5+5*U5*c.^4+4*U6*c.^3+3*U7*c.^2+2*U8*c+U9).*(k+1).*(atan(9*U1*c.^8+8*U2*c.^7+7*U3*c.^6+6*U4*c.^5+5*U5*c.^4+4*U6*c.^3+3*U7*c.^2+2*U8*c+U9)-alpha).^2;
    [L1,L2,L3,L4,L5,L6,L7,L8,L9,~] = deal(Lcoeffs{:});    
    pLbetaL = @(c) atan(9*L1*c.^8+8*L2*c.^7+7*L3*c.^6+6*L4*c.^5+5*L5*c.^4+4*L6*c.^3+3*L7*c.^2+2*L8*c+L9).*(k+1).*(atan(9*L1*c.^8+8*L2*c.^7+7*L3*c.^6+6*L4*c.^5+5*L5*c.^4+4*L6*c.^3+3*L7*c.^2+2*L8*c+L9)-alpha).^2;
    
    %x0U, x0L are the slope of the upper and lower wing contour at the leading edge.
    x0U = U9;
    x0L = L9;

    %xU, xL is the location where the wing contour is tangent to the
    %flow, after which the wing will not experience impact.     
    xU = xU(1);
    xL = xL(1);
       
    if x0U < 0 
        xU = 0;
    end

    %If the wing slope is convex or concave such that impact theory does 
    %not apply, xU, XL = 0         
    if x0L > 0
        xL = 0;
    end 
    CdpW = abs(-integral(pLbetaL,0,xL)-integral(pUbetaU,0,xU));