function CdwW = SprCdwW(M,k,alpha,AR,taper,sweepLE,A2,B2,A3)
%--------------------------------------------------------------------------
% SprCdwW(M,k,alpha,AR,taper,sweepLE,A2,B2,A3)
% SUPERSONIC WING WAVE DRAG COEFFICIENT
% Calculates the supersonic low angle of attack wave drag coeffient for the
% vehicle wing.
%--------------------------------------------------------------------------   
    beta = sqrt(M^2-1);
    %Supersonic factors from Busemann coefficients.    
    C1 = 1/beta;
    C2 = ((M^2-2)^2+k*M^4)/(4*(M^2-1)^2);
    
    CdwW = abs(-8*C2*alpha*A2+2*C1*B2-2*C2*A3);
    
    %Epsilon is the wing sweep measured from the longtidual axis    
    epsilon = pi/2-sweepLE;
    %mu is the angle of the Mach cone radiating from the leading edge of
    %the wing    
    mu = asin(1/M);

    if tan(sweepLE) == (4/AR)*((1-taper)/((1+taper))) %wing type is delta
    %For a delta wing...
        if epsilon < mu 
            %if the leading edge is subsonic...
            CdwW = 0; %there is no wave drag.
        end
    end