function XacW = SprXacW(M,ln,lf,cRoot,sweepLE,taper,AR)
%--------------------------------------------------------------------------
% SprXacW(M,ln,lf,cRoot,sweepLE,taper,AR)
% SUPERSONIC WING AERODYNAMIC CENTRE LOCATION
% Calculates the supersonic low angle of attack aerodynamic centre for the wing.
%--------------------------------------------------------------------------    
    if M > 1.1
        beta = sqrt(M^2-1);
    end
    
    btanSweepData = ones(1,6,6).*[0;1;5;10^7];
    ARtanSweepData = [1,2,3,4,5,6].*ones(4,1,6);

    taperData(:,:,1) = 0.*ones(4,6);
    taperData(:,:,2) = 0.2.*ones(4,6);
    taperData(:,:,3) = 0.25.*ones(4,6);
    taperData(:,:,4) = 0.33.*ones(4,6);
    taperData(:,:,5) = 0.5.*ones(4,6);
    taperData(:,:,6) = ones(4,6);

    xACdata(:,:,1) = [0.16,0.33,0.49,0.66,0.81,0.99;
    0.34,0.46,0.57,0.67,0.78,0.90;
    0.42,0.50,0.58,0.68,0.75,0.85;
    0.42,0.50,0.59,0.68,0.76,0.85];
    xACdata(:,:,2) = [0.20,0.39,0.60,0.80,0.97,1.15;
    0.35,0.53,0.67,0.81,0.96,1.11;
    0.45,0.57,0.70,0.81,0.93,1.04;
    0.46,0.58,0.70,0.81,0.93,1.04];
    xACdata(:,:,3) = [0.23,0.42,0.64,0.82,1.02,1.25;
    0.37,0.55,0.70,0.85,1.01,1.16;
    0.46,0.60,0.73,0.85,0.97,1.10;
    0.48,0.61,0.73,0.85,0.98,1.10];
    xACdata(:,:,4) = [0.23,0.44,0.68,0.87,1.07,1.27;
    0.40,0.58,0.74,0.91,1.08,1.25;
    0.49,0.64,0.79,0.92,1.06,1.20;
    0.50,0.65,0.79,0.92,1.05,1.20];
    xACdata(:,:,5) = [0.25,0.51,0.75,0.99,1.19,1.38;
    0.44,0.64,0.82,1.02,1.22,1.44;
    0.53,0.72,0.89,1.04,1.20,1.37;
    0.55,0.71,0.89,1.06,1.21,1.38];
    xACdata(:,:,6) = [0.35,0.66,0.96,1.20,1.45,1.71;
    0.53,0.84,1.12,1.43,1.71,2.05;
    0.74,1.01,1.24,1.50,1.74,1.99;
    0.76,1.02,1.26,1.51,1.76,1.99];

    %Double interpolation of data, aerodynamic centre referenced from root 
    %chord non-dimensionalised in units of root chords.
    F = griddedInterpolant(btanSweepData,ARtanSweepData,taperData,xACdata);
    XacW = ln+lf+cRoot*F(beta/tan(sweepLE),AR*tan(sweepLE),taper);