function [ClW,ClAlpha,alpha0,clAlpha] = SubClW(M,alpha,AR,taper,sweepLE,airfoilAero)
%--------------------------------------------------------------------------
% SubClW(M,alpha,AR,taper,sweepLE,airfoilAero)
% SUBSONIC WING LIFT COEFFICIENT
% Calculates the subsonic low angle of attack lift coeffient for the
% vehicle wing.
%--------------------------------------------------------------------------
    %Accessing Javafoil data for alpha and lift coefficient.
    alphaTable = airfoilAero(:,1)*(pi/180);
    ClTable = airfoilAero(:,2);
    
    %Calculating ClAlpha for a range of Cl and alpha.    
    ClAlphaTable = zeros(size(airfoilAero,1)-1,1);
    for i = 1:1:size(airfoilAero,1)-1
        ClAlphaTable(i) = (ClTable(i+1)-ClTable(i))/(alphaTable(2)-alphaTable(1));
    end
    alpha0 = alphaTable(1);
    %Infinite span lift curve slope is the mean of the calculated values.        
    clAlpha = mean(ClAlphaTable);
    
    %Adjusted sweep and aspect ratio factors for compressibility effect.        
    sweepLEcomp = atan(sqrt(1-M^2)*tan(sweepLE));
    ARcomp = AR/sqrt(1-M^2);
    
    %Compensating for effect of finite span and compressibility on wing.            
    m = ARcomp/(clAlpha);
        [~,tau] = subsonicSpan(m,taper);   
    ClAlpha = clAlpha/((abs(clAlpha)/(ARcomp*pi))*(1+tau)+sqrt((clAlpha/(ARcomp*pi))^2*(1+tau)^2+1/(cos(sweepLEcomp))^2));
    
    %Calculating total lift coefficient from slope.                
    ClW = ClAlpha*(alpha-alpha0);