function CdiW = TranCdiW(ClW,ClF,CdiWSub,M,Mcr,AR,taper,sweepLE,tBar)
%--------------------------------------------------------------------------
% TranCdiW(ClW,ClF,CdiWSub,M,Mcr,AR,taper,sweepLE,tBar)
% TRANSONIC WING INDUCED DRAG COEFFICIENT
% Calculates the transonic low angle of attack induced drag coeffient for the
% vehicle wing.
%--------------------------------------------------------------------------    
    %The critical mach number parallel to the wing sweep
    McrParallel = MachCr(tBar,AR,0,0);

    %If the swept Mach number is less than the critical Mach number...
    if M*cos(sweepLE) < Mcr
    %... the induced drag is purely subsonic.
        CdiW = CdiWSub;
    else
    %If the swept Mach number is greater than the critical Mach number...        
        %The correction factor delta for the swept and unswept components
        %of the wing are calculated.
        DeltaParallel = fDelta(M,McrParallel);
        DeltaSlip = fDelta(M*cos(sweepLE),Mcr); 
        
        %The area of the wing experiencing swept flow is estimated.
        Sslip = 1 - ((1.23*taper)/(1+taper))^2*(sin(2*sweepLE)/AR)*(2-1.5*(sin(2*sweepLE)/AR)*((taper-1)/(taper+1)));
        
        %The correction factor is calculated from this.        
        Delta = (1/2)*(((1-Sslip)/((cos(sweepLE))^2))*DeltaParallel+(1+Sslip)*cos(sweepLE)*DeltaSlip);
        CdiW = Delta*(ClW+ClF)^2;
    end
    
    %The correction factor delta    
    function Delta = fDelta(M,Mcr)
        %If the mach number is less than one...            
        if M <= 1
            %...the factor is interpolated between the supersonic method at
            %M = 2 and the subsonic Delta value at Mcr, which is zero.
            Mref = 2;
            DeltaRef = (sqrt(Mref^2-1)/4);       
            Delta = (DeltaRef/(Mref-Mcr))*M-((DeltaRef*Mcr)/(Mref-Mcr));
        end
        %If the mach number is greater than one...                    
        if M > 1
            %...the supersonic method is applied.            
            Delta = (sqrt(M^2-1)/4);
        end
    end      
end