function [ClW,ClAlpha,alpha0] = TranClW(ClWSub,ClWSpr,ClAlphaSub,ClAlphaSpr,alpha0Sub,alpha0Spr,M,Mcr,tBar)
%--------------------------------------------------------------------------
% TranClW(ClWSub,ClWSpr,ClAlphaSub,ClAlphaSpr,alpha0Sub,alpha0Spr,M,Mcr,tBar)
% TRANSONIC WING LIFT COEFFICIENT
% Calculates the transonic low angle of attack lift coeffient for the
% vehicle wing.
%--------------------------------------------------------------------------
MU = 1.045;
ML = 0.995;

    if M <= ML
        %For M < 1, the subsonic compressibility factor must be used when 
        %employing the transonic similarity rule.
        tBarcr = ((Mcr^2*betaSub(M)^(3/2))/(M^2*betaSub(Mcr)^(3/2)))*tBar;
        ClW = (tBarcr/tBar)*((betaSub(Mcr))/(betaSub(M)))*ClWSub;
    elseif M >= MU
        %For M > 1, the subsonic compressibility factor must be used when 
        %employing the transonic similarity rule.
        tBarcr = ((1.2^2*(betaSpr(M))^(3/2))/(M^2*(betaSpr(1.2))^(3/2)))*tBar;
        ClW = (tBarcr/tBar)*((betaSpr(1.2))/(betaSpr(M)))*ClWSpr;
    elseif M > ML && M < MU
        %For M ~= 1, an interpolation will be conducted between the just below
        %1 Mach number and the just about 1 Mach number, using the appropriate
        %compressibility factor for each regime.
        tBarcr = ((Mcr^2*betaSub(ML)^(3/2))/(ML^2*betaSub(Mcr)^(3/2)))*tBar;
        ClL = (tBarcr/tBar)*((betaSub(Mcr))/(betaSub(ML)))*ClWSub;
        
        tBarcr = ((1.2^2*(betaSpr(MU))^(3/2))/(MU^2*(betaSpr(1.2))^(3/2)))*tBar;
        ClU = (tBarcr/tBar)*((betaSpr(1.2))/(betaSpr(MU)))*ClWSpr;

        ClW = interp1([ML,MU],[ClL,ClU],M,'linear','extrap');
    end 
    
    %The lift curve slope and zero lift angle of attack are interpolated
    %between the subsonic and supersonic results.
    ClAlpha = interp1([Mcr,1.2],[ClAlphaSub,ClAlphaSpr],M);
    alpha0 = interp1([Mcr,1.2],[alpha0Sub,alpha0Spr],M);
end

function beta = betaSub(M)
    %Subsonic compressibility factor.
    beta = sqrt(1-M^2);
end

function beta = betaSpr(M)
    %Supersonic compressibility factor.
    beta = sqrt(M^2-1);
end