function [del,tau] = subsonicSpan(m, taper)
%--------------------------------------------------------------------------
% subsonicSpan(m, taper)
% SUBSONIC WING LIFT SPAN CORRECTION
% Generates parameters that will be used to scale the wing aerodynamic
% coeffients for the effect of the span.
%--------------------------------------------------------------------------
    mTable = [0.5,0.019,0.1;
    0.75,0.034,0.14;
    1,0.049,0.17;
    1.25,0.063,0.2;
    1.5,0.076,0.22;
    1.75,0.088,0.24];

    taperTable = [1,0.049,0.17;
    4/3,0.026,0.1;
    2,0.011,0.03;
    4,0.016,0.01;
    1000,0.141,0.17];
    
    % Interpolating for the effect of aspect ratio
    F = griddedInterpolant(mTable(:,1), mTable(:,2));
    delM = F(m);
    F = griddedInterpolant(mTable(:,1), mTable(:,3));
    tauM = F(m);

    % Interpolating for the effect of sweep    
    F = griddedInterpolant(taperTable(:,1), taperTable(:,2));
    delTaper = F(taper);
    F = griddedInterpolant(taperTable(:,1), taperTable(:,3));
    tauTaper = F(taper);

    % Parameters to account for sweep and taper (tau for lift coeff, del
    % for drag coeff)
    del = 20.41*delM*delTaper;
    tau = 5.88*tauM*tauTaper;

end