function [Ucoeffs,Lcoeffs,tOfcU,tOfcL,tBar,ctMax,phiTE] = wingProfile(airfoilCoords,coordMid)      
%--------------------------------------------------------------------------
% wingProfile(airfoilCoords,coordMid)
% WING PROFILE GENERATOR
% Generates wing profile symbolic expression for camber and
% coefficients of curve fit, as well as max. thickness of wing and
% trailing edge angle for use in analysis.
%--------------------------------------------------------------------------    

    syms c

    %Upper camber and lower camber coordinates 
    coordsU = airfoilCoords(coordMid:-1:1,:);
    coordsL = airfoilCoords(coordMid:length(airfoilCoords),:);
    
    %Fitting polynomial to match wing profile     
    fitU = fit(coordsU(:,1),coordsU(:,2),'Poly9');
    fitL = fit(coordsL(:,1),coordsL(:,2),'Poly9');
    Ucoeffs = num2cell(coeffvalues(fitU));
    Lcoeffs = num2cell(coeffvalues(fitL));
    
    tOfcCoeffU = coeffvalues(fitU);
    tOfcCoeffL = coeffvalues(fitL);
    
    %Generating polynomial as a symbolic expression
    tOfc = sym('c', [numel(tOfcCoeffU),1]);
    for i = numel(tOfcCoeffU)-1:-1:0
        tOfc(numel(tOfcCoeffU)-(i)) = c.^i;
    end
    
    tOfcU = tOfcCoeffU*tOfc;
    tOfcL = tOfcCoeffL*tOfc;
    tOfcU = vpa(tOfcU,4);
    tOfcL = vpa(tOfcL,4);

    
    %Finding location of max thickness    
    ctMax0 = solve(diff(tOfcU)-diff(tOfcL)==0,c);
    ctMax0 = ctMax0(real(ctMax0)>0&real(ctMax0)<1&imag(ctMax0)==0);
    ctMax = double(ctMax0);

    %Finding max thickness    
    tBar = abs(double(subs(tOfcU,c,ctMax)-subs(tOfcL,c,ctMax)));
    
    %Finding wing trailing edge angle     
    phiTE = double(atan(subs(0.5*diff(tOfcU)+0.5*diff(tOfcL),c,1)));
end