function [i, om_u, a, e, om_l, theta] = ECI2TLE(Rx,Ry,Rz,Vx,Vy,Vz)
%--------------------------------------------------------------------------
% ECI2TLE(Rx,Ry,Rz,Vx,Vy,Vz)
% CONVERTS FROM EARTH CENTRED INERTIAL TO KEPLARIAN ELEMENTS
% X,Y,Z components of radius and velocity. -> %Inclination, longnitude of 
% ascending node, argument of periapsis, true, anomoly, ecccintricity, 
% semi-major axis -> 
%--------------------------------------------------------------------------
    GravE = 3.962717613437675e+14;
    Ix = [1,0,0];
    Iy = [0,1,0];
    Iz = [0,0,1];

    %radius, velocity, angular momentum vector
    R = [Rx,Ry,Rz];
    V = [Vx,Vy,Vz];
    H = cross(R,V);

    N = cross(Iz,H);
    n = norm(N);

    %distance, speed, angular momentum
    r = norm(R);
    v = norm(V);
    h = norm(H);


    %Eccintricity vector
    E = (cross(V,H))/GravE - R/r;

    %Eccintricity
    e = norm(E);

    %Semi-major axis
    a = (h^2/GravE)*(1/(1-e^2));

    %Argument of periapsis
    om_u = atan(dot(N,Iy)/dot(N,Ix));
    if om_u < 0 
        om_u = om_u+2*pi;
    end

    %Inclination
    i = atan(dot(H,cross(N,Iz))/(n*dot(H,Iz)));

    %Longnitude of ascending node
    om_l = atan(dot(E,cross(H,N))/(h*dot(E,N)));
    if om_l < 0
        om_l = om_l+2*pi;
    end

    %True anomoly
    theta = atan(dot(R,cross(H,E))/(h*dot(R,E)));
    if theta < 0 
        theta = theta + 2*pi;
    end