function [Gp, Gv] = FPA2ECI(R,V,gamma,theta,omega,i)
%--------------------------------------------------------------------------
% FPA2ECI(R,V,gamma,theta,omega,i)
% CONVERTS FROM RE-ENTRY SYSTEM TO EARTH CENTRED INERTIAL
% Radial distance, speed, flight path angle, true anomoly, orbital plane
% orientation (longnitude of ascending node, inclination) -> X,Y,Z
% components of distance, velocity
%--------------------------------------------------------------------------
    %X,Y,Z coordinates
    X = R*sin(theta)*cos(i)*sin(omega)+R*cos(theta)*cos(omega);
    Y = R*cos(theta)*sin(omega)-R*sin(theta)*cos(i)*cos(omega);
    Z = R*sin(theta)*sin(i);
    Gp = [X,Y,Z];

    Vt = V*cos(90-gamma+theta);
    Vh = V*sin(90-gamma+theta);

    Vv = Vt*cos(i);
    a = sqrt(Vh^2+Vv^2);

    phi = 90-omega-atan(tan(90-gamma+theta)*(1/cos(i)));

    %X,Y,Z velocity
    Vx = a*cos(phi);
    Vy = a*sin(phi);
    Vz = Vt*sin(i);
    Gv = [Vx,Vy,Vz];