function [Gp, Gv] = TLE2ECI(i,om_u,a,e,om_l,theta)  
%--------------------------------------------------------------------------
% TLE2ECI(i,om_u,a,e,om_l,theta)  
% CONVERTS FROM KEPLARIAN ELEMENTS TO EARTH CENTRED INERTIAL
% Inclination, longnitude of ascending node, argument of periapsis, true
% anomoly, ecccintricity, semi-major axis -> X,Y,Z components of radius 
% and velocity.
%--------------------------------------------------------------------------    
    GravE = 3.962717613437675e+14;

    %Perigee radius, "Rp" 
    Rp = a*(1-e);

    %Specific angular momentum, "h" (at the perigee where theta = 0)
    h = sqrt(Rp*GravE*(1+e));

    %Obtain the Transformation Coordinates from Orbital Parameters
    Px = cosd(om_u)*cosd(om_l)-sind(om_u)*sind(om_l)*cosd(i);
    Py = sind(om_u)*cosd(om_l)+cosd(om_u)*sind(om_l)*cosd(i);
    Pz = sind(om_l)*sind(i);

    Qx = -cosd(om_u)*sind(om_l)-sind(om_u)*cosd(om_l)*cosd(i);
    Qy = -sind(om_u)*sind(om_l)+cosd(om_u)*cosd(om_l)*cosd(i);
    Qz = cosd(om_l)*sind(i);

    Wx = sind(om_u)*sind(i);
    Wy = -cosd(om_u)*sind(i);
    Wz = cosd(i);

    %Obtain the Transformation Matrix
    T = [Px, Qx, Wx; Py, Qy, Wy; Pz, Qz, Wz];

    %Obtain "p" and "v" (Perifocal Position and Velocity Vectors respectively)
    p = (h^2/(GravE*(1+e*cosd(theta))))*[cosd(theta); sind(theta); 0];
    v = (GravE/h)*[-sind(theta); e+cosd(theta); 0];

    %Obtain the Geocentric Equatorial Position & Velocity Vectors (Initial Values)
    Gp = T*p;
    Gv = T*v;
end