function [i,om_u,V0,y0,alt0,theta0,q0,alpha0] = startState()
%--------------------------------------------------------------------------
% startState()
% LOADS INITIAL STATE OF RE-ENTRY VEHICLE FROM USER INPUT
%--------------------------------------------------------------------------
    rE = 6.356766e6;
    GravE = 3.962717613437675e+14;

    disp('Enter which start condition to apply.')

    disp('1: re-entry state')
    disp('2: keplarian elements')
    disp('3: keplarian elements, apogee and perigee radius')
    disp('4: inertial position/velocity vector')
    disp('5: latitude, longnitude, altitude, inertial velocity vector')

    scenario = input('Input: ');

    if scenario == 1 %Re-entry coordinate system

        i = input('Inclination, i (deg): ')*(pi/180);
        om_u = input('Longnitude of ascending node, Omega (deg): ')*(pi/180);
        alt0 = input('Altitude: ');   

        Vc = sqrt(GravE/(rE+alt0));
        a = alt0+rE;
        e = 0.7;
        Va = sqrt(GravE*(1-e)/(a+e));
        Vp = sqrt(GravE*(1+e)/(a+e));   
        
        disp(['Vc = ',num2str(Vc),', Va = ',num2str(Va),', Vp = ',num2str(Vp)]);

        V0 = input('Orbital speed: ');    
        y0 = input('Flight path angle (deg): ')*(pi/180);
        theta0 = input('True anomoly (deg): ')*(pi/180);

    elseif scenario == 2 %Keplarian elements

        i = input('Inclination, i (deg): ')*(pi/180);
        om_u = input('Longnitude of ascending node, Omega (deg): ')*(pi/180);
        a = input('Semi-major axis, a: ');
        e = input('Eccintricity, e: ');
        om_l = input('Argument of perigee, w (deg): ')*(pi/180);
        theta = input('True anomaly, theta (deg): ')*(pi/180);

        %Converting from Keplarian elements to ECI
        [Gr, Gv] = TLE2ECI(i,om_u,a,e,om_l,theta); 

        %Converting from ECI to re-entry coordinates       
        alt0 = norm(Gr) - rE;
        V0 = norm(Gv);
        y0 = atan(e*sin(theta)/(1+e*cos(theta)));
        theta0 = theta;

    elseif scenario == 3 %Keplarian elements but with apogee, perigee radius

        i = input('Inclination, i (deg): ')*(pi/180);
        om_u = input('Longnitude of ascending node, Omega (deg): ')*(pi/180);
        Ra = input('Apogee radius, Ra: ');
        Rp = input('Perigee radius, Rp: ');
        if Rp > Ra
            disp('Apogee radius must be greater than perigee radius');
        end
        om_l = input('Argument of perigee, w (deg): ')*(pi/180);
        theta = input('True anomaly, theta (deg): ')*(pi/180);

        a = (Ra+Rp)/2;
        e = (Ra-Rp)/(Ra+Rp);

        Va = sqrt(GravE*(1-e)/(a+e));
        Vp = sqrt(GravE*(1+e)/(a+e));   
        disp(['Va = ',num2str(Va),', Vp = ',num2str(Vp)]);

        %Converting from Keplarian elements to ECI
        [Gr, Gv] = TLE2ECI(i, om_u, a, e, om_l, theta);  

        %Converting from ECI to re-entry coordinates
        alt0 = norm(Gr) - rE;
        V0 = norm(Gv);
        y0 = atan(e*sin(theta)/(1+e*cos(theta)));
        theta0 = theta;

    elseif scenario == 4 %ECI coordinates

        Rx = input('Radius in x direction, Rx: ');
        Ry = input('Radius in y direction, Ry: ');
        Rz = input('Radius in z direction, Rz: ');
        Vx = input('Velocity in x direction, Vx: ');
        Vy = input('Velocity in y direction, Vy: ');
        Vz = input('Velocity in z direction, Vz: ');

        Gr = [Rx,Ry,Rz];
        Gv = [Vx,Vy,Vz];

        %Converting from ECI to Keplarian elements
        [i, om_u, ~, e, ~, theta] = ECI2TLE(Rx,Ry,Rz,Vx,Vy,Vz);

        %Converting from Keplarian elements to re-entry coordinates        
        alt0 = norm(Gr) - rE;
        V0 = norm(Gv);
        y0 = asin(dot(Gr,Gv)/(norm(Gr)*norm(Gv)));
        y0 = atan(e*sin(theta)/(1+e*cos(theta)));
        theta0 = theta;

    elseif scenario == 5  %Latitude, longnitude, altitude coordinates

        La = input('Latitude angle, La (deg): ')*(pi/180);
        Lo = input('Longitude angle, Lo (deg): ')*(pi/180);
        h = input('Altitude, h: ');
        Vx = input('Velocity in x direction, Vx: ');
        Vy = input('Velocity in y direction, Vy: ');
        Vz = input('Velocity in z direction, Vz: ');

        %Converting from LLH to ECI radius vector        
        Rx = sqrt((1/2)*((h+rE)*cos(La))^2-(tan2(Lo))^2);
        Ry = Rx*tan2(Lo); 
        Rz = (h+rE)*sin(La);

        %Converting from ECI to Keplarian elements
        [i, om_u, ~, e, ~, theta] = ECI2TLE(Rx,Ry,Rz,Vx,Vy,Vz);
        Gr = [Rx,Ry,Rz];
        Gv = [Vx,Vy,Vz];
        
        %Converting from Keplarian elements to re-entry coordinates        
        alt0 = norm(Gr) - rE;
        V0 = norm(Gv);
        y0 = asin(dot(Gr,Gv)/(norm(Gr)*norm(Gv)));
        y0 = atan(e*sin(theta)/(1+e*cos(theta)));
        theta0 = theta;
    end

    %Define initial pitch rate (q0) and angle of attcak (alpha0) for
    %vehicle.
    disp('Now that the orbit is defined, define the body orientation')

    q0 = input('Pitch rate, q0 (deg): ')*(pi/180);
    alpha0 = input('Angle of attack, alpha0 (deg): ')*(pi/180);   
