function Cd = getArianeCd(Mach, alpha)
%--------------------------------------------------------------------------
% getArianeCd(Mach, alpha)
% Calculates ariane drag coefficient from curve-fitted equation
%--------------------------------------------------------------------------    
    %Scale variables for curve fit 
    %alpha -> aoa | [-pi./2,pi./2] -> [-1,1]
    %Mach -> M | [0,10] -> [-1,1]
    M = Mach./5-1;
    aoa = alpha.*2./pi;

    %Load in the coefficients
    a = -0.23904036;
    b = 0.374114442;
    c = 1.48757e-19;
    d = -0.12580021;
    e = -1.4252e-20;
    f = 0.040854248;
    g = 0.207318199;
    h = -0.03533506;
    i = 0.124140439;
    j = 0.141364612;
    k = 1.36402e-19;
    l = 0.014406527;
    m = -3.0077e-20;
    n = 0.109893431;
    o = 0.121903951;
    p = -0.10257872;
    q = -0.18644407;
    r = -0.17354721;
    s = 5.78781e-20;
    t = 0.091552371;
    u = -1.4701e-20;
    v = -0.01499011;
    aa = 0.038519663;
    ab = 0.011355967;
    ac = 0.001001146;
    ad = -0.1726987;
    ae = 4.49135e-20;
    af = 0.026855049;
    ag = -2.8592e-20;
    ah = -0.23393592;
    ai = 0.007705698;
    aj = 0.09545944;
    ak = -0.02289071;
    al = -0.03423153;
    am = 1.90015e-21;

    %Solve the equation
    Cd =(a+d.*T(1,M)+e.*T(1,aoa)+h.*T(2,M)+i.*T(2,aoa)+l.*T(3,M)+m.*T(3,aoa)+p.*T(4,M)+q.*T(4,aoa)+...
     t.*T(5,M)+u.*T(5,aoa)+ab.*T(6,M)+ac.*T(6,aoa)+af.*T(7,M)+ag.*T(7,aoa)+aj.*T(8,M)+ak.*T(8,aoa))./...
    (1+b.*T(1,M)+c.*T(1,aoa)+f.*T(2,M)+g.*T(2,aoa)+j.*T(3,M)+k.*T(3,aoa)+n.*T(4,M)+o.*T(4,aoa)+...
     r.*T(5,M)+s.*T(5,aoa)+v.*T(6,M)+aa.*T(6,aoa)+ad.*T(7,M)+ae.*T(7,aoa)+ah.*T(8,M)+ai.*T(8,aoa)+...
     al.*T(9,M)+am.*T(9,aoa));

     %Scale the output to avoid < 0 drag
    CdMax = 0.8864;
    CdMin = -1.0898;

    Cd = (Cd-(CdMin-0.04)).*(CdMax./(CdMax-(CdMin-0.04)));
end 

function  coeff = T(n,var) 
    coeff = cos(n.*acos(var));
end