function Cl = getArianeCl(Mach, alpha)
%--------------------------------------------------------------------------
% getArianeCl(Mach, alpha)
% Calculates ariane lift coefficient from curve-fitted equation
%--------------------------------------------------------------------------    
    %Scale variables for curve fit
    %alpha -> aoa | [-pi./2,pi./2] -> [-1,1]
    %Mach -> M | [0,10] -> [-1,1]
    M = Mach./5-1;
    aoa = alpha.*2./pi;

    %Load in coefficients
    a = -0.05508136;
    b = 0.598786981;
    c = 0.048713521;
    d = -0.05916188;
    e = 0.156842173;
    f = -0.06473138;
    g = 0.150719974;
    h = 0.006925127;
    i = -0.03709317;
    j = -0.04619282;
    k = -0.11916067;
    l = 0.002692529;
    m = -0.1509388;
    n = 0.061291411;
    o = 0.079302304;
    p = -0.01107764;
    q = -0.07828682;
    r = -0.04573438;
    s = -0.06626214;
    t = 0.008355606;
    u = 0.013381364;
    v = 0.004432392;
    aa = 0.036333875;
    ab = -0.00110031;
    ac = 0.01440614;
    ad = -0.01041563;
    ae = -0.02497775;
    af = 0.003957609;
    ag = 0.006432527;
    ah = -0.03005306;
    ai = 0.016401215;
    aj = 0.00936001;
    ak = 0.000275004;
    al = 0.029512237;
    am = -0.0115452;

    %Solve the equation
    Cl =(a+d.*T(1,M)+e.*T(1,aoa)+h.*T(2,M)+i.*T(2,aoa)+l.*T(3,M)+m.*T(3,aoa)+p.*T(4,M)+q.*T(4,aoa)+...
     t.*T(5,M)+u.*T(5,aoa)+ab.*T(6,M)+ac.*T(6,aoa)+af.*T(7,M)+ag.*T(7,aoa)+aj.*T(8,M)+ak.*T(8,aoa))./...
    (1+b.*T(1,M)+c.*T(1,aoa)+f.*T(2,M)+g.*T(2,aoa)+j.*T(3,M)+k.*T(3,aoa)+n.*T(4,M)+o.*T(4,aoa)+...
     r.*T(5,M)+s.*T(5,aoa)+v.*T(6,M)+aa.*T(6,aoa)+ad.*T(7,M)+ae.*T(7,aoa)+ah.*T(8,M)+ai.*T(8,aoa)+...
     al.*T(9,M)+am.*T(9,aoa));
end

%Function in equation
function  coeff = T(n,var) 
coeff = cos(n.*acos(var));
end