function Cm = getArianeCm(Mach, alpha)
%--------------------------------------------------------------------------
% getArianeCm(Mach, alpha)
% Calculates ariane moment coefficient from curve-fitted equation
%--------------------------------------------------------------------------    
    %Scale variables for curve fit  
    %alpha -> aoa | [-pi./2,pi./2] -> [-1,1]
    %Mach -> M | [0,10] -> [-1,1]
    M = Mach./5-1;
    aoa = alpha.*2./pi;

    %Load in coefficients
    a = 0.346462412;
    b = 0.729795048;
    c = -0.55115008;
    d = 0.085848163;
    e = -0.00547213;
    f = 0.104837714;
    g = -0.65480616;
    h = -0.56278749;
    i = 0.058020695;
    j = -0.20695257;
    k = 0.574656062;
    l = 0.509554821;
    m = 0.082622457;
    n = -0.31810917;
    o = 0.100128689;
    p = -0.64191172;
    q = 0.40169632;
    r = 0.091494104;
    s = -0.55314455;
    t = 0.447130508;
    u = 0.038108765;
    v = 0.351998859;
    aa = -0.64560847;
    ab = -0.41255338;
    ac = 1.076234699;
    ad = 0.567481261;
    ae = -0.36240467;
    af = 0.203144327;
    ag = -0.35448623;
    ah = 0.431823548;
    ai = 0.452098655;
    aj = -0.58770756;
    ak = -0.91468647;
    al = -0.04914921;
    am = 0.464562965;
    an = 0.339802335;
    ao = 0.038636621;
    ap = -0.25123944;
    aq = -0.44702177;
    ar = 0.443284011;
    as = 0.285230207;
    at = -0.16190202;
    au = 0.493337547;
    av = -0.36411861;
    ba = -0.11637405;
    bb = -0.18303093;
    bc = -0.0701726 ;
    bd = 0.248571838;
    be = 0.032258345;
    bf = -0.39274082;
    bg = 0.444581081;
    bh = -0.73929709;
    bi = 0.037771194;
    bj = 0.296764809;
    bk = 0.105489365;         

    %Solve the equation
    Cm =a+b.*M+c.*aoa+d.*S(2,M)+e.*M.*aoa+f.*S(2,aoa)+g.*S(3,M)+h.*S(2,M).*aoa+i.*M.*S(2,aoa)+j.*S(3,aoa)+...
    k.*S(4,M)+l.*S(3,M).*aoa+m.*S(2,M).*S(2,aoa)+n.*M.*S(3,aoa)+o.*S(4,aoa)+...
    p.*S(5,M)+q.*S(4,M).*aoa+r.*S(3,M).*S(2,aoa)+s.*S(2,M).*S(3,aoa)+t.*M.*S(4,aoa)+u.*S(5,aoa)+...
    v.*S(6,M)+aa.*S(5,M).*aoa+ab.*S(4,M).*S(2,aoa)+ac.*S(3,M).*S(3,aoa)+ad.*S(2,M).*S(4,aoa)+ae.*M.*S(5,aoa)+af.*S(6,aoa)+...
    ag.*S(7,M)+ah.*S(6,M).*aoa+ai.*S(5,M).*S(2,aoa)+aj.*S(4,M).*S(3,aoa)+ak.*S(3,M).*S(4,aoa)+al.*S(2,M).*S(5,aoa)+am.*M.*S(6,aoa)+an.*S(7,aoa)+...
    ao.*S(8,M)+ap.*S(7,M).*aoa+aq.*S(6,M).*S(2,aoa)+ar.*S(5,M).*S(3,aoa)+as.*S(4,M).*S(4,aoa)+at.*S(3,M).*S(5,aoa)+au.*S(2,M).*S(6,aoa)+av.*M.*S(7,aoa)+ba.*S(8,aoa)+...
    bb.*S(9,M)+bc.*S(8,M).*aoa+bd.*S(7,M).*S(2,aoa)+be.*S(6,M).*S(3,aoa)+bf.*S(5,M).*S(4,aoa)+bg.*S(4,M).*S(5,aoa)+bh.*S(3,M).*S(6,aoa)+bi.*S(2,M).*S(7,aoa)+bj.*M.*S(8,aoa)+bk.*S(9,aoa);
end

%Function in the equation
function coeff = S(n,var)
    coeff = -1+2./(1+exp(-(var+1-(n-1).*(2./9))./0.12));
end