function Cd = getShuttleCd(Mach, alpha)
%--------------------------------------------------------------------------
% getShuttleCd(Mach, alpha)
% Calculates shuttle drag coefficient from curve-fitted equation
%--------------------------------------------------------------------------    
    %alpha -> aoa | [-pi./2,pi./2] -> [0,pi]
    %Mach -> M | [0,10] -> [0,pi]
    M = Mach.*pi./10;
    aoa = alpha+pi./2;

    %Load equation coefficients 
    a = 157.2356816;
    b = 3.171584829;
    c = 1.8109e-12;
    d = -266.404173;
    e = 12.98328418;
    f = -184.090155;
    g = -12.3067652;
    h = -4.50650485;
    i = -8.2967e-13;
    j = -3.02943325;
    k = -4.4661e-13;
    l = 94.71200017;
    m = 4.821002596;
    n = 33.91761325;
    o = 1.792620235;
    p = 1.096277138;
    q = 1.82371e-13;
    r = 0.434152332;
    s = 3.91522e-14;
    t = -6.64193086;
    u = -0.420697 ;
    v = -1.9312e-13;
    aa = -2.39961366;
    ab = -2.6206e-12;
    ac = -1.52594743;
    ad = -1.5459e-12;
    ae = 1.22497e-13;
    af = 1.72053e-13;
    ag = 7.07159e-14;
    ah = 1.13984e-13;
    ai = 0.012970577;
    aj = 6.32712e-13;
    ak = 0.00461791;
    al = 1.38314e-13;
    am = -2.2882e-14;
    an = -4.0431e-14;
    ao = -41.9304269;
    ap = 6.829109449;
    aq = -27.9771475;
    ar = 7.13977e-13;
    as = 3.311128212;
    at = 2.13385e-13;
    au = 1.188076159;
    av = 0.167738203;
    ba = 14.69748712;
    bb = 0.1156182;
    bc = 3.929544147;
    bd = -4.4526e-14;
    be = 0.567392111;
    bf = 4.258760237;
    bg = 2.87646e-13;
    bh = 2.218647476;
    bi = 4.0588e-14;
    bj = 1.165412893;
    bk = -0.12986675;
    bl = -0.84453719;
    bm = -4.6407e-14;
    bn = -1.2171e-14;
    bo = -1.6737e-14;
    bp = -0.06294882;
    bq = -6.9953e-14;
    
    %Solve the equation
    Cd = a+b.*cos(M)+c.*cos(aoa)+d.*sin(M)+e.*sin(aoa)+f.*cos(2.*M)+g.*cos(2.*aoa)+h.*sin(2.*M)+i.*sin(2.*aoa)+...
    j.*cos(3.*M)+k.*cos(3.*aoa)+l.*sin(3.*M)+m.*sin(3.*aoa)+n.*cos(4.*M)+o.*cos(4.*aoa)+p.*sin(4.*M)+q.*sin(4.*aoa)+...
    r.*cos(5.*M)+s.*cos(5.*aoa)+t.*sin(5.*M)+u.*sin(5.*aoa)+...
    v.*cos(M).*cos(aoa)+aa.*cos(M).*sin(aoa)+ab.*sin(M).*cos(aoa)+ac.*cos(M).*cos(2.*aoa)+...
    ad.*cos(2.*M).*cos(aoa)+ae.*cos(M).*sin(2.*aoa)+af.*sin(3.*M).*cos(aoa)+ag.*cos(M).*cos(3.*aoa)+...
    ah.*cos(3.*M).*cos(aoa)+ai.*cos(M).*sin(3.*aoa)+aj.*sin(3.*M).*cos(aoa)+ak.*cos(M).*cos(4.*aoa)+...
    al.*cos(4.*M).*cos(aoa)+am.*cos(M).*sin(4.*aoa)+an.*sin(4.*M).*cos(aoa)+ao.*sin(M).*sin(aoa)+...
    ap.*sin(M).*cos(2.*aoa)+aq.*cos(2.*M).*sin(aoa)+ar.*sin(M).*sin(2.*aoa)+as.*sin(2.*M).*sin(aoa)+...
    at.*sin(M).*cos(3.*aoa)+au.*cos(3.*M).*sin(aoa)+av.*sin(M).*sin(3.*aoa)+ba.*sin(3.*M).*sin(aoa)+...
    bb.*sin(M).*cos(4.*aoa)+bc.*cos(4.*M).*sin(aoa)+bd.*sin(M).*sin(4.*aoa)+be.*sin(4.*M).*sin(aoa)+...
    bf.*cos(2.*M).*cos(2.*aoa)+bg.*cos(2.*M).*sin(2.*aoa)+bh.*sin(2.*M).*cos(2.*aoa)+bi.*cos(2.*M).*cos(3.*aoa)+...
    bj.*cos(3.*M).*cos(2.*aoa)+bk.*cos(2.*M).*sin(3.*aoa)+bl.*sin(3.*M).*cos(2.*aoa)+bm.*sin(2.*M).*sin(2.*aoa)+...
    bn.*sin(2.*M).*cos(3.*aoa)+bo.*cos(3.*M).*sin(2.*aoa)+bp.*sin(2.*M).*sin(3.*aoa)+bq.*sin(3.*M).*sin(2.*aoa);

    %Scale the output to correct for Cd < 0
    CdMax = 2.1703;
    CdMin = -0.2580;

    Cd = (Cd-(CdMin-0.04)).*(CdMax./(CdMax-(CdMin-0.04)));
end