function Cl = getShuttleCl(Mach,alpha)
%--------------------------------------------------------------------------
% getShuttleCl(Mach, alpha)
% Calculates shuttle lift coefficient from curve-fitted equation
%--------------------------------------------------------------------------    
    %Scale variables for curve fit
    %alpha -> aoa | [-pi./2,pi./2] -> [-1,1]
    %Mach -> M | [0,10] -> [-1,1]
    M = Mach./5-1;
    aoa = alpha.*2./pi;

    %Load the coefficients
    a = -0.05309279;
    b = 0.614436096;
    c = 0.076511937;
    d = -0.06180211;
    e = 0.149281291;
    f = -0.0521019;
    g = 0.151367784;
    h = 0.006467319;
    i = -0.03877016;
    j = -0.05351191;
    k = -0.11119824;
    l = 0.003620217;
    m = -0.14910221;
    n = 0.065522;
    o = 0.091919534;
    p = -0.01212048;
    q = -0.08405668;
    r = -0.0440042;
    s = -0.06017752;
    t = 0.008757475;
    u = 0.017513355;
    v = -0.00246993;
    aa = 0.039002096;
    ab = -0.00074162;
    ac = 0.015025465;
    ad = -0.01303295;
    ae = -0.02266373;
    af = 0.003886515;
    ag = 0.002488564;
    ah = -0.03343191;
    ai = 0.015027731;
    aj = 0.010053346;
    ak = -0.00084285;
    al = 0.025920178;
    am = -0.01021499;

    %Solve the equation    
    Cl =(a+d.*T(1,M)+e.*T(1,aoa)+h.*T(2,M)+i.*T(2,aoa)+l.*T(3,M)+m.*T(3,aoa)+p.*T(4,M)+q.*T(4,aoa)+...
     t.*T(5,M)+u.*T(5,aoa)+ab.*T(6,M)+ac.*T(6,aoa)+af.*T(7,M)+ag.*T(7,aoa)+aj.*T(8,M)+ak.*T(8,aoa))./...
    (1+b.*T(1,M)+c.*T(1,aoa)+f.*T(2,M)+g.*T(2,aoa)+j.*T(3,M)+k.*T(3,aoa)+n.*T(4,M)+o.*T(4,aoa)+...
     r.*T(5,M)+s.*T(5,aoa)+v.*T(6,M)+aa.*T(6,aoa)+ad.*T(7,M)+ae.*T(7,aoa)+ah.*T(8,M)+ai.*T(8,aoa)+...
     al.*T(9,M)+am.*T(9,aoa));
end 

function  coeff = T(n,var) 
    coeff = cos(n.*acos(var));
end