function Cm = getShuttleCm(Mach,alpha)
%--------------------------------------------------------------------------
% getShuttleCm(Mach, alpha)
% Calculates shuttle moment coefficient from curve-fitted equation
%--------------------------------------------------------------------------
    %Scale variables for curve fit
    %alpha -> aoa | [-pi./2,pi./2] -> [0,pi]
    %Mach -> M | [0,10] -> [0,pi]
    M = Mach.*pi./10;
    aoa = alpha+pi./2;

    %Load the coefficients
    a = 0.180350203;
    b = 0.015777855;
    c = -0.14117249;
    d = 0.012489176;
    e = -0.12018653;
    f = 0.146169872;
    g = 0.00739936;
    h = -0.06015518;
    i = 0.017290611;
    j = 0.130692873;
    k = 0.002943652;
    l = -0.02927995;
    m = 0.013988855;
    n = 0.116630677;
    o = -0.04249767;
    p = -0.00095251;
    q = -0.00275526;
    r = 0.009173683;
    s = 0.059286459;
    t = 0.000746732;
    u = 0.016497623;
    v = -0.00442101;
    aa = 0.008523515;
    ab = 0.004400011;
    ac = 0.031839871;
    ad = 0.000749394;
    ae = 0.020737259;
    af = 0.001630323;
    ag = -0.00650794;
    ah = 0.021325047;
    ai = -0.00292258;
    aj = -0.00196076;
    ak = 0.000932405;
    al = 0.005115264;
    am = 0.000102125;
    an = -0.01671263;
    ao = -0.00589506;
    ap = 0.025111168;
    aq = -0.00509515;
    ar = -0.01650054;
    as = 0.000841139;
    at = -0.00125134;
    au = 5.03618e-06;
    av = -0.0256722;
    ba = -0.00054211;
    bb = -0.00824564;
    bc = 0.024826206;
    bd = -0.00834879;
    be = -0.02866065;
    bf = 0.000738957;
    bg = -0.0028907;
    bh = -4.3068e-05;
    bi = -0.00548911;
    bj = -4.9573e-05;
    bk = 0.019221637;
    bl = -0.00736668;
    bm = 0.027070928;
    bn = -0.01384999;
    bo = -0.04305194;
    bp = 0.000614432;
    bq = -0.00696332;
    br = -1.3738e-05;
    bs = 0.005998417;
    bt = 1.21752e-05;
    bu = 0.026556173;
    bv = -0.00051493;

    %Solve the equation
    Cm = a+b.*cos(M)+c.*cos(aoa)+d.*cos(2.*M)+e.*cos(M).*cos(aoa)+f.*cos(2.*aoa)+...
    g.*cos(3.*M)+h.*cos(2.*M).*cos(aoa)+i.*cos(M).*cos(2.*aoa)+j.*cos(3.*aoa)+...
    k.*cos(4.*M)+l.*cos(3.*M).*cos(aoa)+m.*cos(2.*M).*cos(2.*aoa)+n.*cos(M).*cos(3.*aoa)+o.*cos(4.*aoa)+...
    p.*cos(5.*M)+q.*cos(4.*M).*cos(aoa)+r.*cos(3.*M).*cos(2.*aoa)+s.*cos(2.*M).*cos(3.*aoa)+t.*cos(M).*cos(4.*aoa)+u.*cos(5.*aoa)+...
    v.*cos(6.*M)+aa.*cos(5.*M).*cos(aoa)+ab.*cos(4.*M).*cos(2.*aoa)+ac.*cos(3.*M).*cos(3.*aoa)+ad.*cos(2.*M).*cos(4.*aoa)+ae.*cos(M).*cos(5.*aoa)+...
    af.*cos(6.*aoa)+...
    ag.*cos(7.*M)+ah.*cos(6.*M).*cos(aoa)+ai.*cos(5.*M).*cos(2.*aoa)+aj.*cos(4.*M).*cos(3.*aoa)+ak.*cos(3.*M).*cos(4.*aoa)+al.*cos(2.*M).*cos(5.*aoa)+...
    am.*cos(M).*cos(6.*aoa)+an.*cos(7.*aoa)+...
    ao.*cos(8.*M)+ap.*cos(7.*M).*cos(aoa)+aq.*cos(6.*M).*cos(2.*aoa)+ar.*cos(5.*M).*cos(3.*aoa)+as.*cos(4.*M).*cos(4.*aoa)+at.*cos(3.*M).*cos(5.*aoa)+...
    au.*cos(2.*M).*cos(6.*aoa)+av.*cos(M).*cos(7.*aoa)+ba.*cos(8.*aoa)+...
    bb.*cos(9.*M)+bc.*cos(8.*M).*cos(aoa)+bd.*cos(7.*M).*cos(2.*aoa)+be.*cos(6.*M).*cos(3.*aoa)+bf.*cos(5.*M).*cos(4.*aoa)+bg.*cos(4.*M).*cos(5.*aoa)+...
    bh.*cos(3.*M).*cos(6.*aoa)+bi.*cos(2.*M).*cos(7.*aoa)+bj.*cos(M).*cos(8.*aoa)+bk.*cos(9.*aoa)+...
    bl.*cos(10.*M)+bm.*cos(9.*M).*cos(aoa)+bn.*cos(8.*M).*cos(2.*aoa)+bo.*cos(7.*M).*cos(3.*aoa)+bp.*cos(6.*M).*cos(4.*aoa)+bq.*cos(5.*M).*cos(5.*aoa)+...
    br.*cos(4.*M).*cos(6.*aoa)+bs.*cos(3.*M).*cos(7.*aoa)+bt.*cos(2.*M).*cos(8.*aoa)+bu.*cos(M).*cos(9.*aoa)+bv.*cos(10.*aoa);
end