function x0 = Ariane_initial(p)
%--------------------------------------------------------------------------
% Ariane_initial(p) 
% Prepares the initial guess for the solver for the Ariane model
%--------------------------------------------------------------------------
	% linear guess functions
    fV0 = @(t) (p.prob.Vf - p.prob.V0)/(p.t{end}(end) - p.t{1}(1))*t + p.prob.V0;
    fgamma0 = @(t) (p.prob.gammaf - p.prob.gamma0)/(p.t{end}(end) - p.t{1}(1))*t + p.prob.gamma0;
    fh0 = @(t) (p.prob.hf - p.prob.h0)/(p.t{end}(end) - p.t{1}(1))*t + p.prob.h0;
    fr0 = @(t) (p.prob.rf - p.prob.r0)/(p.t{end}(end) - p.t{1}(1))*t + p.prob.r0;
    fm0 = @(t) (p.prob.mf - p.prob.m0)/(p.t{end}(end) - p.t{1}(1))*t + p.prob.m0;

    fU10 = @(t,u0,uf) (uf - u0)/(p.t{end}(end) - p.t{1}(1))*t + u0;
    fU20 = @(t,u0,uf) (uf - u0)/(p.t{end}(end) - p.t{1}(1))*t + u0;
    fU30 = @(t,u0,uf) (uf - u0)/(p.t{end}(end) - p.t{1}(1))*t + u0;

    V0 = []; gamma0 = []; h0 = []; r0 = []; m0 = []; q0 = []; alpha0 = []; U10 = []; U20 = []; U30 = [];
    
	for i = 1:length(p.Narray)
	    V0 = [V0;fV0(p.t{i})]; % velocity initial guess
	    gamma0 = [gamma0;fgamma0(p.t{i})]; % flight path initial guess
	    h0 = [h0;fh0(p.t{i})]; % altitude initial guess
	    r0 = [r0;fr0(p.t{i})]; % latitude initial guess
	    m0 = [m0;fm0(p.t{i})]; % mass initial guess

	    U10 = [U10;fU10(p.t{i},0,0)]; % control initial guess
        U20 = [U20;fU20(p.t{i},0,0)]; % control initial guess
        U30 = [U30;fU30(p.t{i},0,0)]; % control initial guess

    end

    % time guess for time-free problems
    if p.varTF == 0
        tguess = [];
    else
        tguess = p.prob.tf;
    end
    
	% combine to column vector
	x0 = [reshape(V0,[],1);reshape(gamma0,[],1);reshape(h0,[],1);reshape(r0,[],1);reshape(m0,[],1);reshape(U10,[],1);reshape(U20,[],1);reshape(U30,[],1);tguess];
end