function [t,X,U,exitflag,output] = Ariane_main(X0)
%--------------------------------------------------------------------------
% Ariane_main(X0)
% Set up for the Ariane solver, input starting states fed in
%--------------------------------------------------------------------------    
    % problem functions
    p.func.deriv = @Ariane_deriv; % derivative function name
    p.func.lagrange = @Ariane_lagrange; % Lagrange term function name
    p.func.mayer = @Ariane_mayer; % Mayer term function name
    p.func.path = @Ariane_path; % path constraint function name
    p.func.boundary = @Ariane_boundary; % boundary constraint function name
    p.func.bounds = @Ariane_bounds; % variables bounds function name
    p.func.initial = @Ariane_initial; % initial guess function name

    % initial states
    prob.V0 = X0(1); 
    prob.gamma0 = X0(2); 
    prob.h0 = X0(3); 
    prob.r0 = X0(4); 
    prob.m0 = X0(5); 

    % guess for final states
    prob.Vf = 5;
    prob.gammaf = 90*pi/180; 
    prob.hf = 0;
    prob.rf = pi/16; 
    prob.mf = 197700; 

    prob.t0 = 0; % initial time
    prob.tf = 800; % final time
    p.prob = prob;

    % number of states and controls
    p.ns = 5; % states
    p.nu = 3; % controls

    % variable final time problem
    p.varTF = 1; % 0:no, 1:yes

    % choice of pseudospectral method
    p.opts.method = 'CGL'; % either LGL or CGL

    % scale problem
    p.opts.scale = 0; % 0:no, 1:yes

    % plot flag
    p.opts.plotflag = 0; % 0:no, 1:yes

    % save flag
    p.opts.saveflag = 1; % 0:no, 1:yes

    % number of iterations
    p.opts.fmincon.MaxIter = 500;
    p.opts.fmincon.Display = 'iter';

    % mesh
    p.Tarray = linspace(0,1,3); % segment boundaries
    p.Narray = 6.*ones(1,length(p.Tarray)-1)+1; % number of nodes per segment

    % solve the problem
    [t,X,U,f,p,exitflag,output] = PS_Solve(p);