function [t,X,U,exitflag,output] = Shuttle_main(X0)
%--------------------------------------------------------------------------
% Shuttle_main(X0)
% Set up for the Shuttle solver, input starting states fed in
%--------------------------------------------------------------------------    
    % problem functions
    p.func.deriv = @Shuttle_deriv; % derivative function name
    p.func.lagrange = @Shuttle_lagrange; % Lagrange term function name
    p.func.mayer = @Shuttle_mayer; % Mayer term function name
    p.func.path = @Shuttle_path; % path constraint function name
    p.func.boundary = @Shuttle_boundary; % boundary constraint function name
    p.func.bounds = @Shuttle_bounds; % variables bounds function name
    p.func.initial = @Shuttle_initial; % initial guess function name

    % initial states
    prob.V0 = X0(1); 
    prob.gamma0 = X0(2); 
    prob.h0 = X0(3); 
    prob.r0 = X0(4); 
    prob.q0 = X0(6); 
    prob.alpha0 = X0(7); 

    % guess for final states
    prob.Vf = 1000;
    prob.gammaf = 20*pi/180; 
    prob.hf = 0;
    prob.rf = pi/16; 
    prob.qf = 0; 
    prob.alphaf = 0; 

    prob.t0 = 0; % initial time (required)
    prob.tf = 800; % final time (required)
    p.prob = prob;

    % number of states and controls
    p.ns = 6; % states
    p.nu = 3; % controls

    % variable final time problem
    p.varTF = 1; % 0:no, 1:yes

    % choice of pseudospectral method
    p.opts.method = 'CGL'; % either LGL or CGL

    % scale problem
    p.opts.scale = 0; % 0:no, 1:yes

    % plot flag
    p.opts.plotflag = 0; % 0:no, 1:yes

    % save flag
    p.opts.saveflag = 1; % 0:no, 1:yes
    
    % number of iterations
    p.opts.fmincon.MaxIter = 500;
    p.opts.fmincon.Display = 'iter';

    % mesh number    
    p.Tarray = linspace(0,1,3); % segment boundaries
    p.Narray = 6.*ones(1,length(p.Tarray)-1)+1; % number of nodes per segment

    % solve the problem
    [t,X,U,f,p,exitflag,output] = PS_Solve(p);